********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 5: GENERATES DEMOGRAPHIC, EDUCATION, LABOR MARKET, AND OTHER DERIVED VARIABLES
*
* Created by: N. Millan's December 27, 2012 do-file
* Education section updated by: G. Pierre, T. Rajadel and S. Monroy in December 12, 2013, and T. Rajadel in February 7, 2014
* Hours variable corrected by: T. Rajadel and S. Monroy in Sept 25, 2013
* Modified by: Sebastian Monroy Taborda 
* Created: December 27, 2012
* Last updated: May 2, 2014
********************************************************************************************************************

/*
As of May 2,2014 the wave 2 STEP countries are:
	- Ghana
	- Armenia
	- Georgia
	- Macedonia
	- Kenya
	
This do file uses STEP data to:
	1. Create demographic variables:
		age age_g age_g2 age2 gender marital_status life_sat chronic 
	2. Create education-related variables:
		ece, certificate, current, dropout, interrupt, training, apprenticeship
		ISCED, ISCED_v, ISCED_p, highest_field_1, highest_field_2, current_ISCED, current_ISCED_v, current_field, dropout_ISCED, 
		dropout_level dropout_field training_field_1 training_field_2
	3. Create labor market variables
	4. Others

It is based on Natalia Millan's December 27, 2012 do-file.

*/


global pathworkingdata


foreach country in "Armenia" "Georgia" "Ghana" "Macedonia" "Kenya" {
use "$pathworkingdata/STEP `country'_working.dta", clear

***************************************************************************************************************
************************** AGE, AGE GROUPS, GENDER AND OTHER DEMOGRAPHIC VARS *********************************
***************************************************************************************************************
*GENDER
if country=="Kenya" {
drop age gender
}
gen gender =1 if m1a_q02 ==2
replace gender=0 if m1a_q02 ==1
label define gender 1 "Female" 0 "Male" 
label values gender gender
label var gender Gender

*AGE
gen age=m1a_q04

*AGE SQUARED
gen age2=age*age


*MARITAL STATUS /*DUMMY equal to one if person has a spouse*/
if country=="Kenya"{

gen has_spouse=1 if m1a_q13==1|m1a_q13==2|m1a_q13==3
replace has_spouse=0 if inrange(m1a_q13,4,12)
replace has_spouse=0 if m1a_q13==97
}
else {

gen has_spouse=1 if m1a_q13==1|m1a_q13==2 
replace has_spouse=0 if inrange(m1a_q13,3,12)
}
label 	var	has_spouse	"Has a spouse"
*replace marital_stat=5 if m1a_q13==8
*label define marital_stat 1 "Married/Cohab" 2 "Sep/Div" 3 "Widowed" 4 "Single" 5 "Other", replace


*LIFE SATISFACTION
gen life_sat=m3_q01
replace life_sat=.a if life_sat==92 | life_sat<0
label var life_sat "Life satisfaction"
 
*HAS A CHRONIC DISEASE
if country=="Georgia"{
recode m3_q05(0=2)
}
recode m3_q05(2=0), gen(chronic)
label define chronic 1 "Has a chronic disease" 0 "Doesn't have a chronic disease", replace
label values chronic chronic
label var chronic "Chronic disease" 

*Take skips on account for Kenya
recode m3_q06 (-44=.b)

*NUMBER OF SIBLINGS AT AGE 12

gen old_brothers=m7_q17
gen old_sisters=m7_q18
gen young_brothers=m7_q19
gen young_sisters=m7_q20
replace old_brothers=.a if inrange(m7_q17,-100,-1) 
replace old_sisters=.a if inrange(m7_q18,-100,-1) 
replace young_brothers=.a if inrange(m7_q19,-100,-1) 
replace young_sisters=.a if inrange(m7_q20,-100,-1) 
label var young_brothers "Number of younger brothers at age 12"
label var young_sisters "Number of younger sisters at age 12"
label var old_brothers "Number of younger brothers at age 12"
label var old_sisters "Number of older sisters at age 12"



*FAMILY STRUCTURE AT AGE 12 
if country=="Georgia"{
foreach var of varlist	m7_q03 m7_q06 m7_q07 m7_q09 m7_q11 m7_q14 m7_q21_1 ///
						m7_q21_2 m7_q21_3 m7_q21_4 m7_q21_5 m7_q21_6 m7_q21_7 ///
						m7_q21_8 m7_q21_9 m7_q21_10 m7_q21_11 m7_q21_12 m7_q21_13 ///
						m7_q21_14 m7_q23_1 m7_q23_2 m7_q23_3 m7_q23_4 m7_q23_5 ///
						m7_q23_6 m7_q23_7 m7_q23_8 m7_q23_9 m7_q23_10 m7_q23_11 ///
						m7_q24 m7_q05_1_a m7_q05_1_b m7_q05_2_a m7_q05_2_b m7_q05_3_a ///
						m7_q05_3_b m7_q05_4_a m7_q05_4_b m7_q05_5_a m7_q05_5_b ///
						m7_q05_6_a m7_q05_6_b m7_q05_7_a m7_q05_7_b {
recode `var' (0=2)
label values `var' yes_no
}
}


gen father_mother=1 if m7_q21_1 ==1 & m7_q21_2==1
replace father_mother=0 if m7_q21_1==2 & m7_q21_2==2
replace father_mother=2 if father_mother==.
label define father_mother 0 "Didn't live with father & mother"  1 "Lived with father & mother" 2 "DK/RF" 
label values father_mother father_mother
label var father_mother "Lived with mother and father at age 12"

*NUMBER OF SHOCKS BEFORE AGE 15
if country=="Georgia" { 
foreach num of numlist 1/11 {
foreach var of varlist m7_q23_`num' {
recode m7_q23_`num' (2=0)
}
}
}
else { 
foreach num of numlist 1/12 {
foreach var of varlist m7_q23_`num' {
recode m7_q23_`num' (2=0)
}
}
}
if country=="Georgia" {
gen shocks=(m7_q23_1 + m7_q23_2 + m7_q23_3 + m7_q23_4 + m7_q23_5 + m7_q23_6  + m7_q23_7 + m7_q23_8 + m7_q23_9 + m7_q23_10 + m7_q23_11 )
}  
else {
gen shocks=(m7_q23_1 + m7_q23_2 + m7_q23_3 + m7_q23_4 + m7_q23_5 + m7_q23_6  + m7_q23_7 + m7_q23_8 + m7_q23_9 + m7_q23_10 + m7_q23_11 + m7_q23_12 )  
}
replace shocks=. if inrange(shocks,-72,-1)
label var shocks "Number of economic shocks before age 15" 
gen shocks2=shocks	
replace shocks2=2 if shocks2>=2 & shocks2<.
label define shocks2 0 "No shocks" 1 "One shock" 2 "Two or more shocks", replace
label values  shocks2 shocks2
label var shocks2 "Index for number of economic shocks before age 15" 
display "`country'" 
tab shocks2 if elegido==1, m


gen shocks_dummy=0 if shocks2==0	
replace shocks_dummy=1 if shocks2>=1 & shocks2<=2
label define shocks_dummy 0 "No shocks" 1 "At least one shock", replace
label values  shocks_dummy shocks_dummy
label var shocks_dummy "Dummy for economic shocks before age 15" 
*OVERWEIGHT, UNDERWEIGHT AND OBESITY
		recode m3_q03 (888=.) (9=.) (0=.) (-9/-1=.) (-99=.) (-66=.)/*WEIGHT*/
		recode m3_q02 (888=.) (9=.) (0=.) (-9/-1=.) (-99=.) (-66=.)/*HEIGHT*/ 
		
		replace m3_q02=m3_q02/100 /*Convert centimeters to meters*/
		gen BMI=m3_q03/(m3_q02*m3_q02) if !missing(m3_q03,m3_q02) /*Weight over height squared*/
		replace BMI=round(BMI, .1)
		gen  BMI_class=1 if  BMI <18.5
		replace BMI_class=2 if BMI>18.5 & BMI<25
		replace BMI_class=3 if BMI>=25 & BMI <=29
		replace BMI_class=4 if BMI>=30 & BMI<. 
		label define BMI_class 1 Underweight 2 Normal 3 Overweight 4 Obese, replace 
		label values BMI_class BMI_class
		label var BMI_class "BMI classification" 
		label var BMI "Body Mass Index" 
		notes  BMI: "A BMI under 16 is extremely emaciated; a BMI of 15 signals starvation. BMI's over 40 signal morbid obesity." 


*PARENTAL INVOLVEMENT IN EDUCATION
	gen parental =m2_q44 if inrange(m2_q44,-1,8)
	label var parental "Parental involvement in education"
*SOCIOECONOMIC STATUS AT AGE 15
recode m7_q22 (-9/0=.) (1=1) (2=1) (3=1) (4=2) (5=2) (6=2) (7=3) (8=3) (9=3) (10=3), gen(ses)
replace ses=. if ses>10 | ses<0
label define ses 1 "Low SES" 2 "Middle SES" 3 "High SES", replace
label values ses ses
label var ses "Socioeconomic status at age 15"	
	
	
****** MOTHER TONGUE ******

if country=="Ghana" {
	gen mother_tongue= 1 if (m7_q01_1==1 & m7_q01_2==.) | (m7_q01_2==1 & m7_q01_1==.) | (m7_q01_1==1 & m7_q01_2==1) /*Akan Only*/
	replace mother_tongue=2 if (m7_q01_1==1 & m7_q01_2~=1 & m7_q01_2<.) | (m7_q01_2==1 & m7_q01_1~=1 & m7_q01_1<.) /* Akan and Others*/
	replace mother_tongue=3 if mother_tongue==. & (m7_q01_1!=. | m7_q01_2!=.) /* Others only*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Akan only" 2 " Akan and Other" 3 "Other only" 
	lab values mother_tongue mother_tongue
}

if country=="Armenia"{ 
	recode m7_q01_1 m7_q01_2 (-9/-1=.)
	gen mother_tongue=1 if (m7_q01_1==1 & m7_q01_2==.) | (m7_q01_2==1 & m7_q01_1==.) /* Armenian only */
	replace mother_tongue=2 if (m7_q01_1==1 & m7_q01_2~=1 & m7_q01_2<.) | (m7_q01_2==1 & m7_q01_1~=1 & m7_q01_1<.) /* Armenian and others */
	replace mother_tongue=3 if mother_tongue==. & (m7_q01_1!=. | m7_q01_2!=.) /* Others only*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Armenian only" 2 " Armenian and Other" 3 "Other only" 
	lab values mother_tongue mother_tongue

}

if country=="Georgia" {
	gen mother_tongue=1 if m7_q01_1==1 & m7_q01_2==0 & m7_q01_3==0 & m7_q01_4==0 & m7_q01_5==0 /* Georgian Only */
	replace mother_tongue=2 if m7_q01_1==1 & (m7_q01_2==1 | m7_q01_3==1 | m7_q01_4==1 | m7_q01_5==1) /* Georgian and Others*/
	replace mother_tongue=3 if m7_q01_1==0 & (m7_q01_2==1 | m7_q01_3==1 | m7_q01_4==1 | m7_q01_5==1) /* Others only*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Georgian only" 2 " Georgian and Other" 3 "Other only" 
	lab values mother_tongue mother_tongue

}

if country=="Macedonia" {
	gen mother_tongue=1 if (m7_q01_1==1 & m7_q01_2==.) | (m7_q01_2==1 & m7_q01_1==.)	 							/* Macedonian Only */
	replace mother_tongue=2 if (m7_q01_1==1 & m7_q01_2~=1 & m7_q01_2<.) | (m7_q01_2==1 & m7_q01_1~=1 & m7_q01_1<.)	/* Macedonian and Others*/
	replace mother_tongue=3 if (m7_q01_1==2 & m7_q01_2==.) | (m7_q01_2==2 & m7_q01_1==.)							/* Albanian Only */
	replace mother_tongue=4 if mother_tongue==. & (m7_q01_1!=. | m7_q01_2!=.) 										/* Others only*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Macedonian only" 2 "Macedonian and Other" 3 "Albanian only" 4 "Others Only"
	lab values mother_tongue mother_tongue
}

if country=="Kenya" {
	recode m7_q01_2 (-77=.) 
	gen mother_tongue=1 if (m7_q01_1==1 & m7_q01_2==.) | (m7_q01_2==1 & m7_q01_1==.)	 							/* Swahili Only */
	replace mother_tongue=2 if (m7_q01_1==1 & m7_q01_2~=1 & m7_q01_2<.) | (m7_q01_2==1 & m7_q01_1~=1 & m7_q01_1<.)	/* Swahili and Others*/
	replace mother_tongue=3 if (m7_q01_1==2 & m7_q01_2==.) | (m7_q01_2==2 & m7_q01_1==.)							/* Kikuyu Only */
	replace mother_tongue=4 if mother_tongue==. & (m7_q01_1!=. | m7_q01_2!=.) 										/* Others only*/
	label var mother_tongue "Mother tongue"
	lab define mother_tongue 1 "Swahili only" 2 "Swahili and Other" 3 "Kikuyu only" 4 "Others Only"
	lab values mother_tongue mother_tongue
}	
****************************************** END OF AGE, AGE GROUPS, GENDER AND OTHER DEMOGRAPHIC VARS ******************************************


***************************************************************************************************************************
**************************************** LABOR MARKET *********************************************************************
***************************************************************************************************************************
/*"Employed" if:
- worked at least one hour in the past 7 days (q01-03)
- OR reported undertaking an occasional job in the past 7 days (q04)
- OR is currently absent from a permanent / long term job and will return to the same job (q05 & q06) */

/*  "Unemployed":
- did not work in the past 7 days (answered no to q01 to q04)
- AND is not currently absent from a permanent / long term job (no to q05) OR will not be returning to the same job (yes to q05, but either no or doesn't know to q06)
- AND is looking for a job (q07) or trying to set up a business (q08)
- AND is available to start work within the next two weeks */

/*"Out of the Labor Force if he or she:
- did not work in the past 7 days (answered no to q01 to q04)
- AND is not currently absent from a permanent / long term job (no to q05) OR will not be returning to the same job (yes to q05, but either no or doesn't know to q06)
- AND: 		(i) is NOT looking for a job (q07) NOR trying to set up a business (q08) 
		OR (ii) is looking for a job (q07) OR trying to set up a business (q08) AND, in either case, is not available to start work within the next two weeks (q12)*/

*emp: Dummy variable for worked or held a job in the past week
if country=="Kenya" {
mvdecode m4a* m4b* m4c*, mv(-77/-44=.)
} 
	gen emp=1 if m4a_q01==1|m4a_q02==1|m4a_q03==1|m4a_q04==1|m4a_q05==1|m4a_q06==1
	replace emp=0 if m4a_q01==2 & m4a_q02==2 & m4a_q03==2 & m4a_q04==2 & m4a_q05==2 
	replace emp=0 if m4a_q06==2
	label var emp "Currently working"
	
*lm_status: Labor market status (employed, unemployed, inactive)	
	gen lm_status=1 if emp==1
	replace lm_status=2 if m4a_q07==1 & m4a_q12==1 /*Looking for work and available in next 2 weeks*/
	replace lm_status=2 if m4a_q08==1 & m4a_q12==1 /*Trying to start business and available in next 2 weeks*/
	replace lm_status=3 if m4a_q07==2 & m4a_q08==2  /*Hasn't looked for work/tried to start a business*/
	replace lm_status=3 if m4a_q07==1 & m4a_q12==2 /*Looking for work but not available in next 2 weeks*/
	replace lm_status=3 if m4a_q08==1 & m4a_q12==2 /*Trying to start business but not available in next 2 weeks*/
	label define  lm_status 1 "Employed" 2 "Unemployed" 3 "Inactive", replace
	label values lm_status lm_status
	label var lm_status "Labor market status"

	tab lm_status, m
	
if country=="Armenia" { 
	replace emp=1 if lm_status==3 & emp==1
}
if country=="Georgia" {
	replace emp=1 if lm_status==2 & emp==1
}

*active: Dummy variable for being active in the labor market
	gen active=1 if lm_status==1|lm_status==2
	replace active=0 if lm_status==3 
	label define active 1 Active 0 Inactive
	label values active active
	label var active "Dummy for active in the labor market"

*emp_stat: employment status
	gen emp_status=.
	replace emp_status=1 if m4c_q06==1 & emp==1
	replace emp_status=2 if m4c_q06==2 & emp==1
	replace emp_status=3 if m4c_q06==3 & emp==1
	replace emp_status=3 if  emp==1 & (m4c_q06~=1 & m4c_q06~=2 & m4c_q06~=3)
	lab define emp_status 1 "Employee" 2 "Self-employed" 3 "Unpaid family worker/other", replace
	lab values emp_status emp_status
	lab var emp_status "Employment status" 
	tab emp_status, m
	
*self_emp: SELF-EMPLOYMENT DUMMY
gen self_emp=1 if emp_stat==2
replace self_emp=0 if emp_stat==1
replace self_emp=0 if emp_stat==3
label var self_emp "Self-employment dummy"
label define self_emp 1 "Self-employed" 0 "Employee/Unpaid family worker/other", replace
label values self_emp self_emp 
	
*emplast12: DUMMY VARIABLE FOR WORKING OR WORKED IN THE LAST 12 MONTHS
	gen emplast12=1 if emp==1							/*Currently working*/	
	replace emplast12=1 if m5a_q02==1   				/*Worked in last 12 months*/
	replace emplast12 =0 if emp<. & emplast12==.
	label var emplast12 "Currently working or worked in last 12 months"

*emp6: DUMMY VARIABLE FOR INDIVIDUALS WHO HAVE WORKED AT LEAST 6 MONTHS SINCE COMPLETED HIGHEST LEVEL OF EDUCATION

if country=="Georgia" {
foreach var of varlist 	m2_q01 m2_q02 m2_q04 m2_q05 m2_q10 m2_q14 ///
						m2_q17 m2_q19 m2_q22 m2_q27 m2_q28 m2_q34 ///
						m2_q37 m2_q39 m2_q41 {
	recode `var' (0=2)
	lab values `var' yes_no
}
}
	
	gen emp6=1 if m2_q27==1
	replace emp6 =0 if m2_q27==2  
	label var emp6 "Worked at least 6 months since completed highest level of education"
	notes emp6: Those currently attending formal ed (or w/o formal ed) do not answer this question. 

*Unemployed: 1=unemployed, 0=employed
gen unemployed=1 if lm_status==2
replace unemployed=0 if lm_status==1
label var unemployed "1=unemployed, 0=employed" 

*Employment
gen employed=1 if emp==1
		replace employed=0 if emp!=1 & lm_status<.
		label var employed "1=employed, 0=not employed"

*Wage workers
gen wage_worker=1 if emp_status==1
replace wage_worker=0 if emp==1 & emp_status!=1
label define wage_worker 1 "Wage-worker" 0 "Self-employed or family worker" 
label values wage_worker wage_worker
label var wage_worker "Percent of wage workers" 

*INACTIVE
if country=="Ghana" {
gen inactive=.
replace inactive=1 if m4a_q09==3 /*Housewife*/
replace inactive=2 if m4a_q09==4|m4a_q09==5  /*Retired/old age*/
replace inactive=3 if m4a_q09==1|m4a_q09==2 /*student*/
replace inactive=4 if m4a_q09==6|m4a_q09==8 /*unfit, don't want to work*/
replace inactive=5 if m4a_q09==13|m4a_q09==14 /*Discouraged*/
replace inactive=6 if m4a_q09==7|m4a_q09==9|m4a_q09==10|m4a_q09==11|m4a_q09==12 /*In transition*/
replace inactive=7 if m4a_q09==15 /*Other*/
replace inactive=8 if lm_stat==3 & inactive==. /*Looking for work but not available in 2 weeks*/
label define inactive 1 "Housework" 2 "Retired/old age" 3 "Student/Apprenticeship" 4 "Unfit" 5 "Discouraged" 6 "In transition" 7 "Other " 8 "Looking for work, not available in next 2 weeks" , replace
label values inactive inactive
label var inactive "Types of inactive population"
display "`country'"
tab inactive
}

if country=="Armenia" | country=="Georgia" | country=="Macedonia" {
gen inactive=.
replace inactive=1 if m4a_q09==2 /*Housewife*/
replace inactive=2 if m4a_q09==3|m4a_q09==4  /*Retired/old age*/
replace inactive=3 if m4a_q09==1 /*student*/
replace inactive=4 if m4a_q09==5|m4a_q09==7 /*unfit, don't want to work*/
replace inactive=5 if m4a_q09==12|m4a_q09==13 /*Discouraged*/
replace inactive=6 if m4a_q09==6|m4a_q09==8|m4a_q09==9|m4a_q09==10|m4a_q09==11 /*In transition*/
replace inactive=7 if m4a_q09==14 /*Other*/
replace inactive=8 if lm_stat==3 & inactive==. /*Looking for work but not available in 2 weeks*/
label define inactive 1 "Housework" 2 "Retired/old age" 3 "Student/Apprenticeship" 4 "Unfit" 5 "Discouraged" 6 "In transition" 7 "Other " 8 "Looking for work, not available in next 2 weeks" , replace
label values inactive inactive
label var inactive "Types of inactive population"
display "`country'"
tab inactive, m
}

if country=="Kenya" {
gen inactive=.
replace inactive=1 if m4a_q09==2 /*Housewife*/
replace inactive=2 if m4a_q09==3|m4a_q09==4  /*Retired/old age*/
replace inactive=3 if m4a_q09==1 /*student*/
replace inactive=4 if m4a_q09==5|m4a_q09==7 /*unfit, don't want to work*/
replace inactive=5 if m4a_q09==12|m4a_q09==13 /*Discouraged*/
replace inactive=6 if m4a_q09==6|m4a_q09==8|m4a_q09==9|m4a_q09==10|m4a_q09==11 /*In transition*/
replace inactive=7 if m4a_q09==97 /*Other*/
replace inactive=8 if lm_stat==3 & inactive==. /*Looking for work but not available in 2 weeks*/
label define inactive 1 "Housework" 2 "Retired/old age" 3 "Student/Apprenticeship" 4 "Unfit" 5 "Discouraged" 6 "In transition" 7 "Other " 8 "Looking for work, not available in next 2 weeks" , replace
label values inactive inactive
label var inactive "Types of inactive population"
display "`country'"
tab inactive, m
}

*OCCUPATION
*recoding occupation
if country=="Macedonia" {
rename m5a_q01_c m5a_q01_occ_code
rename m5a_q02_c m5a_q02_occ_code
}

if country=="Kenya" {
gen m5a_q01_occ_code=m4c_q01_code if m5a_q01==1
gen m5a_q02_occ_code=m4a_q20_code if m5a_q02==1

order m5a_q01_occ_code, after(m5a_q01_occ)
order m5a_q02_occ_code, after(m5a_q02_occ)
}

recode m5a_q01_occ_code m5a_q02_occ_code (-9/-1=.) (-77/-44=.)

gen occupationcode=.
replace occupationcode=m5a_q01_occ_code if m5a_q01_occ_code<.
replace occupationcode=m5a_q02_occ_code if m5a_q01_occ_code==.
label var occupationcode "ISCO Rev.8 occupation code"

gen occupation=.
replace occupation=1 if occupationcode>=110 & occupationcode<=149
replace occupation=2 if occupationcode>=210 & occupationcode<=269
replace occupation=3 if occupationcode>=310 & occupationcode<=369
replace occupation=4 if occupationcode>=410 & occupationcode<=449
replace occupation=5 if occupationcode>=510 & occupationcode<=549
replace occupation=6 if occupationcode>=610 & occupationcode<=639
replace occupation=7 if occupationcode>=700 & occupationcode<=759
replace occupation=8 if occupationcode>=810 & occupationcode<=879
replace occupation=9 if occupationcode>=910 & occupationcode<=969
replace occupation=0 if occupationcode>=0 & occupationcode<=40
label var occupation "1-digit ISCO Rev.8 occupation code"

if country=="Armenia"{
replace occupation=2 if occupationcode==26 /* Assume it is occupation related to 2 digit level*/
replace occupation=3 if occupationcode==31 /* Assume it is occupation related to 2 digit level*/
replace occupation=5 if occupationcode>=51 & occupationcode<=54 /* Assume it is occupation related to 2 digit level*/
replace occupation=7 if occupationcode>=71 & occupationcode<=74 /* Assume it is occupation related to 2 digit level*/
}

sum occupation m5a_q01_occ_code m5a_q02_occ_code

*OCCUPATION TYPE
gen occtype=1 if occupation==1 | occupation==2 | occupation==3
replace occtype=2 if occupation>=4 & occupation<=9 
replace occtype=. if emp!=1 /*Only define this variable for currently employed*/

label define occtype 1 "Type A" 2 "Type B", replace
label values occtype occtype
tab occtype, gen(occtype)
rename occtype1 type_a
rename occtype2 type_b
label var type_a "Type A occupation"
label var type_b "Type B occupation"


	*OCCUPATION TYPE STEP Aggregation
	gen occtype_step=.
	replace occtype_step=1 if occupationcode>=110 & occupationcode<=369
	replace occtype_step=2 if occupationcode>=410 & occupationcode<610
	replace occtype_step=5 if (occupationcode>=610 & occupationcode<=639)
	replace occtype_step=3 if occupationcode>=700 & occupationcode<=879
	replace occtype_step=4 if occupationcode>=910 & occupationcode<=969
	replace occtype_step=0 if occupationcode>=0 & occupationcode<=40
	if country=="Armenia"{
		replace occtype_step=1 if occupationcode==26 /* Assume it is occupation related to 2 digit level*/
		replace occtype_step=1 if occupationcode==31 /* Assume it is occupation related to 2 digit level*/
		replace occtype_step=2 if occupationcode>=51 & occupationcode<=54 /* Assume it is occupation related to 2 digit level*/
		replace occtype_step=3 if occupationcode>=71 & occupationcode<=74 /* Assume it is occupation related to 2 digit level*/
}
	
	
	label define occtype_step 0 "Military personnel" 1 "Highly skilled white collar - Managers/Professionals/Technicians" 2 "Low skilled white collar" ///
	                      3 "Crafts and related trades workers; Plant and machine operator and assemblers" 4 "Elementary occupations" 5 "Skilled agriculture work", replace
	label value occtype_step occtype_step
	label var occtype_step "Occupation type (STEP Aggregation)"

	*LAST OCCUPATION FOR UNEMPLOYED/INACTIVE
	if country=="Kenya"{
	rename m4a_q20 m4a_q20_a
	rename m4a_q20_code m4a_q20
	}
	
	
	recode m4a_q20 (-9/-1=.)
	gen last_occ_inun=.
	replace last_occ_inun=1 if m4a_q20>=110 & m4a_q20<=369
	replace last_occ_inun=2 if m4a_q20>=410 & m4a_q20<610
	replace last_occ_inun=5 if m4a_q20>=610 & m4a_q20<=639
	replace last_occ_inun=3 if m4a_q20>=700 & m4a_q20<=879
	replace last_occ_inun=4 if m4a_q20>=910 & m4a_q20<=969
	replace last_occ_inun=0 if m4a_q20>=0 & m4a_q20<=40
	
	if country=="Armenia"{
		replace last_occ_inun=1 if m4a_q20==2 /* Assume it is last_occ_inun related to 2 digit level*/
		replace last_occ_inun=1 if m4a_q20==31 /* Assume it is last_occ_inun related to 2 digit level*/
		replace last_occ_inun=2 if m4a_q20==42 /* Assume it is last_occ_inun related to 2 digit level*/
		replace last_occ_inun=3 if m4a_q20>=71 & m4a_q20<=74 /* Assume it is last_occ_inun related to 2 digit level*/
	}
	label value last_occ_inun occtype_step
	label var last_occ_inun "Last occupation for inactive/unemployed (STEP Aggregation)" 
	
	*OCCUPATION FOR PEOPLE WHO WORKED IN LAST 12 MONTHS
	destring m4a_q20, replace
	gen     occtype_step_emp12=1 if m4a_q20>=110 &  m4a_q20 <=369
	replace occtype_step_emp12=2 if  m4a_q20>=410 &  m4a_q20<610
	replace occtype_step_emp12=5 if m4a_q20>=610 & m4a_q20<=639
	replace occtype_step_emp12=3 if m4a_q20>=700 & m4a_q20<=879
	replace occtype_step_emp12=4 if m4a_q20>=910 & m4a_q20<=969
	replace occtype_step_emp12=0 if m4a_q20>=0 & m4a_q20<=40
	
	if country=="Armenia"{
		replace occtype_step_emp12=1 if m4a_q20==2 /* Assume it is last_occ_inun related to 2 digit level*/
		replace occtype_step_emp12=1 if m4a_q20==31 /* Assume it is last_occ_inun related to 2 digit level*/
		replace occtype_step_emp12=2 if m4a_q20==42 /* Assume it is last_occ_inun related to 2 digit level*/
		replace occtype_step_emp12=3 if m4a_q20>=71 & m4a_q20<=74 /* Assume it is last_occ_inun related to 2 digit level*/
	}
	label values occtype_step_emp12 occtype_step
	label var occtype_step_emp12 "Most recent occupation for those who worked in last 12 months (STEP Aggregation)"	
		
	*ADDITIONAL OCCUPATION INACTIVE & UNEMPLOYED COULD DO (FIRST LISTED, USING TYPE 3 DEFINITION)
	if country=="Kenya"{
	rename m4a_q30_1 m4a_q30_1a
	rename m4a_q30_code1 m4a_q30_1
	rename m4a_q30_2 m4a_q30_2a
	rename m4a_q30_code2 m4a_q30_2
	}
	
	recode m4a_q30_1 (-9/-1=.)
	gen     ad_occ_inun=.
	replace ad_occ_inun=1 if m4a_q30_1>=110 & m4a_q30_1<=369
	replace ad_occ_inun=2 if  m4a_q30_1>=410 &  m4a_q30_1<610
	replace ad_occ_inun=5 if m4a_q30_1>=610 & m4a_q30_1<=639
	replace ad_occ_inun=3 if m4a_q30_1>=700 & m4a_q30_1<=879
	replace ad_occ_inun=4 if m4a_q30_1>=910 & m4a_q30_1<=969
	replace ad_occ_inun=0 if m4a_q30_1>=0 & m4a_q30_1<=40
	label value ad_occ_inun occtype_step
	if country=="Armenia"{
		replace ad_occ_inun=1 if m4a_q30_1>=21 & m4a_q30_1<=36/* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_inun=2 if m4a_q30_1==42 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_inun=2 if m4a_q30_1==52 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_inun=3 if m4a_q30_1==71 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_inun=4 if m4a_q30_1==91 /* Assume it is last_occ_inun related to 2 digit level*/
	}
	label var ad_occ_inun "First additional occupation, inactive/unemployed (STEP Aggregation)" 
	
	*ADDITIONAL OCCUPATION FOR PEOPLE CURRENTLY WORKING /*LIMITED TO THE FIRST ONE LISTED*/
	if country=="Georgia" {
	foreach var of varlist m4b_q09 m4b_q10 {
	recode `var'(0=2)
	lab values `var' yes_no
	}
	}
	
	if country=="Kenya"{
	rename m4b_q11_1 m4b_q11_1a
	rename m4b_q11_code1 m4b_q11_1
	rename m4b_q11_2 m4b_q11_2a
	rename m4b_q11_code2 m4b_q11_2
	rename m4b_q11_3 m4b_q11_3a
	rename m4b_q11_code3 m4b_q11_3
	}
	
	recode m4b_q11_1 (-9/-1=.)
	gen     ad_occ_current=1 if m4b_q11_1>=110 &  m4b_q11_1<=369
	replace ad_occ_current=2 if m4b_q11_1>=410 &  m4b_q11_1<610
	replace ad_occ_current=5 if m4b_q11_1>=610 & m4b_q11_1<=639
	replace ad_occ_current=3 if m4b_q11_1>=700 & m4b_q11_1<=879
	replace ad_occ_current=4 if m4b_q11_1>=910 & m4b_q11_1<=969
	replace ad_occ_current=0 if m4b_q11_1>=0 & m4b_q11_1<=40
	if country=="Armenia"{
		replace ad_occ_current=1 if m4b_q11_1>=21 & m4b_q11_1<=36/* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_current=2 if m4b_q11_1==44 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_current=3 if m4b_q11_1==71 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_current=3 if m4b_q11_1==74 /* Assume it is last_occ_inun related to 2 digit level*/
	}	
	label values ad_occ_current occtype_step
	label var ad_occ_current "First additional occupation, currently working (STEP Aggregation)"
	notes ad_occ_current: Refers to first additional occupation the person could work as. 
	
	*ADDITIONAL OCCUPATION FOR PEOPLE WHO WORKED IN LAST 12 MONTHS /*LIMITED TO THE FIRST ONE LISTED*/
	destring m4a_q30_1, replace
	gen     ad_occ_emp12=1 if m4a_q30_1>=110 &  m4a_q30_1 <=369
	replace ad_occ_emp12 =2 if  m4a_q30_1>=410 &  m4a_q30_1<610
	replace ad_occ_emp12 =5 if m4a_q30_1>=610 & m4a_q30_1<=639
	replace ad_occ_emp12 =3 if m4a_q30_1>=700 & m4a_q30_1<=879
	replace ad_occ_emp12 =4 if m4a_q30_1>=910 & m4a_q30_1<=969
	replace ad_occ_emp12 =0 if m4a_q30_1>=0 & m4a_q30_1<=40
	if country=="Armenia"{
		replace ad_occ_emp12=1 if m4a_q30_1>=21 & m4a_q30_1<=36/* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_emp12=2 if m4a_q30_1==42 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_emp12=2 if m4a_q30_1==52 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_emp12=3 if m4a_q30_1==71 /* Assume it is last_occ_inun related to 2 digit level*/
		replace ad_occ_emp12=4 if m4a_q30_1==91 /* Assume it is last_occ_inun related to 2 digit level*/
	}
	label values ad_occ_emp12 occtype_step
	
	label var ad_occ_emp12 "First additional occupation, emp last 12 months (STEP Aggregation)"
	notes ad_occ_emp12: Refers to first additional occupation the person could work as. 

	*PERMANENT POSITION 
	mvdecode m4c*, mv(-44=.)
	mvdecode m4c*, mv(-9/-1=.)
	gen permanent=1 if m4c_q22==4
	replace permanent=0 if m4c_q22<4 & m4c_q22<.
	replace permanent=0 if m4c_q22==5
	label var permanent "Permanent position" 
	notes permanent: Corresponds to main job. 

	*GOVERNMENT EMPLOYMENT
	/*NOTE: Dummy only takes on values for employees. Should it be also take into account the self-employed in the zero category?*/
	*Dummy for government employee
	gen pub_emp=1 if m4c_q19==1|m4c_q19==2
	replace pub_emp=0 if m4c_q19<. & pub_emp!=1
	label var pub_emp "Public/Private employee"
	label define pub_emp 1 "public sector" 0 "private sector", replace
	label values pub_emp pub_emp
	label var pub_emp "Public or private sector employee"
	notes pub_emp: 1 = govt employee, 0=private employee
	notes pub_emp: Corresponds to main job. 

	*SIZE OF ESTABLISHMENT
	if country=="Georgia" {
	foreach var of varlist m4c_q10 m4c_q11 m4c_q13 m4c_q14 m4c_q16 m4c_q17 m4c_q21 m4c_q28 m4c_q29 {
	recode `var' (0=2)
	lab values `var' yes_no
	} 
	}
	
	mvdecode m4c*, mv(-9/-1=.)
	gen size_est=1 if m4c_q20==1
	replace size_est=3 if inrange(m4c_q20, 4, 8)
	replace size_est=2 if inrange(m4c_q20, 2, 3)
	replace size_est=1 if m4c_q17==2 & size_est==./*Self-employed who do not have paid employees*/
	replace size_est=1 if m4c_q16==2 & size_est==./*Self-employed who do not have unpaid employees*/ 
	label define size_est 1 "One" 2 "2 to 15" 3 "16 and more", replace
	label values size_est size_est
	label var size_est "Category for number of paid workers in establishment"
	notes size_est: Corresponds to main job. 	
	tab size_est, gen(firm)
	label var firm1 "Firm with one worker"
	label var firm2 "Firm with 2 to 15 workers"
    label var firm3 "Firm with 16 or more workers"
	
	*EMPLOYMENT CONTRACT
	gen contract=1 if m4c_q18==1| m4c_q18==2
	replace contract=0 if m4c_q18==3
	label var contract "Has written employment contract" 
	notes contract: Corresponds to main job. 
	
	*SOCIAL SECURITY BENEFITS
	gen benefits =1 if m4c_q21==1
	replace benefits=0 if m4c_q21==2
	label var benefits "Receives social security benefits at work" 
	
	*INFORMAL/FORMAL
	/* Assumptions:
		1. Individuals who are currently working and reported not having social security or benefits are informal
		2. Individuals who reported being an unpaid worke on family business are informal
		3. Individuals who reported being self employed and their reported size of establishment is 1 (including themselves) are informal
	*/
	gen informal=1 if benefits==0
	replace informal=0 if benefits==1  
	replace informal=1 if (m4c_q06==3 | m4c_q06==5) & emp==1 /* ASSUMPTION: INDIVIDUALS WHO REPORTED 
																			BEING AN UNPAID WORKER IN FAMILY BUSINES*/
	replace informal=1 if (m4c_q06==2 & size_est==1 & emp==1) & informal==. /* ASSUMPTION: INDIVIDUALS WHO REPORTED ///
																							BEING SELF EMPLOYED AND DO NOT HAVE PAID WORKERS ARE CONSIDERED INFORMAL*/
	label define informal 1 "Informal" 0 "Formal" 
	label values informal informal
	label var informal "Informal dummy"	
	
	gen informal_wage=1 if informal==1 & wage_worker==1
	replace informal_wage=0 if informal==0 & wage_worker==1
	gen informal_self=1 if informal==1 & self_emp==1
	replace informal_self=0 if informal==0 & self_emp==1
	label define informal_wage 1 "Informal wage worker" 0 "Formal wage worker", replace
	label values informal_wage informal_wage
	label var informal_wage "Informal (only wage workers)"
	label define informal_self 1 "Informal self-employed" 0 "Formal self-employed", replace
	label values informal_self informal_self
	label var informal_self "Informal (only self-employed)"
	notes  informal: "Informality is defined as having SS benefits through job" 
	notes  informal_wage: "Informality is defined as having SS benefits through job/unpaid family worker/other" 
	notes  informal_self: "Informality is defined as having SS benefits through job/unpaid family worker/other" 
	
*TENURE IN CURRENT JOB (use number of months so the variable can be squared)
	/*Note: some people have been working zero months*/

	 foreach var of varlist m4c_q03_m m4c_q03_y  {	 /*Change non-response to missing*/
		replace `var' = . if `var'==99
		}
	recode m4c_q03_? (-9/-1=.) (-77/-66=.)
	
	 gen tenure=m4c_q03_m
	 replace tenure =(m4c_q03_y*12) if tenure==.
	 replace tenure =(m4c_q03_y*12) if tenure==0
	 replace tenure=m4c_q03_m if m4c_q03_m==0 & m4c_q03_y==.
     gen tenure_squared=tenure*tenure           
	 label var tenure "Number of months in current job"
	 label var tenure_squared "Tenure squared"
	 
*EXPERIENCE NEEDED FOR JOB
	gen exp_needed=m5b_q25
	replace exp_needed=. if inrange(exp_needed,-9,-1) | exp_needed==9
	label define m5b_q25 1 "None" 2 "Less than 1 year" 3 "1-2 years" 4 "3-5 years" 5 "6-10 years" 6 "More than 10 years", replace 
	label values exp_needed m5b_q25
	label var exp_needed "Years of work experience needed for the job"
	notes exp_needed: Corresponds to main job. 

*TIME NEEDED TO DO A GOOD JOB
	gen time_needed=m5b_q26
	replace time_needed=. if inrange(time_needed,-9,-1) | time_needed==9
	label define time_needed 1 "Less than 1 week" 2 "1 week to 1 month" 3 "1-6 months" ///
							4 "7-12 months" 5 "More than 1 year" 6 "More than 10 years", replace 
	label values time_needed time_needed
	label var time_needed "Time to learn to do job well with experience and education needed"
	notes time_needed: Corresponds to main job.

*DOES PERSON'S TENURE FALL WITHIN THE TIME TO DO A GOOD JOB CATEGORIES?
	gen tenure_range=1 if tenure==0|tenure==1
	replace tenure_range=3 if tenure>=1 & tenure<=6
    replace tenure_range=4 if tenure>=7 & tenure<=12
	replace tenure_range=5 if tenure>12 & tenure<=120
	replace tenure_range=6 if tenure>120 & tenure<.
	*Combine less than a week with 1 week to a month
	recode time_needed (2=1), gen(time_needed2)
	
	gen tenure_dif=1 if (tenure_range-time_needed2)<0
	replace tenure_dif=2 if (tenure_range-time_needed2)==0
	replace tenure_dif=3 if (tenure_range-time_needed2)>0 & (tenure_range-time_needed2)<.
	label define tenure_dif 1 "Has less tenure than needed" 2 "Has same tenure as needed" 3 "Has more tenure than needed", replace
	label values tenure_dif tenure_dif
	label var tenure_dif "Difference between tenure and time needed to do job well" 
	
	drop time_needed2
	
*DIF B/T AGE & AGE AT END OF STUDIES
	recode m2_q26 (-9/-1=.) (-77/-44=.)
	gen exp_proxy=age-m2_q26
	label var exp_proxy "Diference between age and aprox age at end of studies"
	replace exp_proxy=. if exp_proxy<0 /*This variable should not be negative*/

*ECONOMIC SECTOR OF MAIN JOB
if country=="Kenya" {
	foreach i in 1 4{ 
	rename m4b_q0`i'_1 m4b_q0`i'_1a
	rename m4b_q0`i'_code1 m4b_q0`i'_1
	rename m4b_q0`i'_2 m4b_q0`i'_2a
	rename m4b_q0`i'_code2 m4b_q0`i'_2
	rename m4b_q0`i'_3 m4b_q0`i'_3a
	rename m4b_q0`i'_code3 m4b_q0`i'_3
	rename m4b_q0`i'_4 m4b_q0`i'_4a
	rename m4b_q0`i'_code4 m4b_q0`i'_4
	}
	}
	destring m4b_q04_*, replace
	recode m4b_q04_? (-9/-1=.)

	gen econ_sector=m4b_q04_1 if m4b_q01_1==m4c_q01_code
	replace econ_sector = m4b_q04_2 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_2  /*For ppl whose main occupation was listed second*/
	replace econ_sector = m4b_q04_3 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_3  /*For ppl whose main occupation was listed third*/	

	
if country=="Ghana" {		/*economic sector coded to 2 digits, ISIC rev.4*/
	replace econ_sector=1 if econ_sector>=1 & econ_sector<=9  /*Agriculture, fishery, mining*/
	replace econ_sector=2 if econ_sector>=10 & econ_sector<=33 /*Manufacturing*/
	replace econ_sector=4 if econ_sector>=35 & econ_sector<=39 /*Other services*/ 
	replace econ_sector=2 if econ_sector>=41  & econ_sector<=43 /*Construction*/
	replace econ_sector=3 if econ_sector>=45  & econ_sector<=47 /*Commerce*/
	replace econ_sector=4 if econ_sector>=49  & econ_sector<=99 /*Other services*/
}

if country=="Armenia" | country=="Georgia" | country=="Macedonia" | country=="Kenya" {		/*economic sector coded to 2 digits, ISIC rev.4*/
	replace econ_sector=1 if econ_sector>=10 & econ_sector<=99  /*Agriculture, fishery, mining*/
	replace econ_sector=2 if econ_sector>=100 & econ_sector<=339 /*Manufacturing*/
	replace econ_sector=4 if econ_sector>=350 & econ_sector<=399 /*Other services*/ 
	replace econ_sector=2 if econ_sector>=410  & econ_sector<=439 /*Construction*/
	replace econ_sector=3 if econ_sector>=450  & econ_sector<=479 /*Commerce*/
	replace econ_sector=4 if econ_sector>=490  & econ_sector<=999 /*Other services*/
}

/* Macedonia: observation with economic sector 447, such code does not exist. It should be 474, but they have to 
confirm. 


. list cluster hhn idcode econ_sector if econ_sector==447

      +-----------------------------------+
      | cluster   hhn   idcode   econ_s~r |
      |-----------------------------------|
1869. |     225    25        2        447 |
      +-----------------------------------+

*/

	label var econ_sector "Economic sector"
	label define econ_sector 1 "Agriculture, fishery, mining" 2 "Manufacturing & construction" 3 "Commerce"  4 "Other services", replace
	label values econ_sector econ_sector		
	
*FOR SELF-EMPLOYED: WOULD LIKE TO EXPAND BUSINESS
gen expand=1 if m4c_q10==2
replace expand=2 if m4c_q11==1
replace expand=3 if m4c_q11==2
label define expand 1 "No" 2 "Yes, but constraint" 3 "Yes, no constraint" 
label var expand "Desire to expand business and if so, if face constraints"
label values expand expand

*NET PROFIT (FOR SELF-EMPLOYED)
if country=="Macedonia" {
	rename m4c_q09_c m4c_q09_amnt
	rename m4c_q09_tp m4c_q09_period
}

recode m4c_q09_amnt m4c_q09_period (-9/-1=.) (-99/-66=.)
gen net_profit =.
replace net_profit=.a if m4c_q09_amnt==92
replace net_profit =.a if m4c_q09_amnt==1.2 /*STRANGE NUMBER*/
replace net_profit=m4c_q09_amnt*4 if m4c_q09_period==1 /*week*/
replace net_profit=m4c_q09_amnt if m4c_q09_period==2 /*month*/
replace net_profit=m4c_q09_amnt*2 if m4c_q09_period==3 /*fortnight*/
replace net_profit=m4c_q09_amnt/3 if m4c_q09_period==4 /*trimester*/
replace net_profit=m4c_q09_amnt/6 if m4c_q09_period==5 /*semester*/
replace net_profit=m4c_q09_amnt/12 if m4c_q09_period==6 /*year*/
replace net_profit=m4c_q09_amnt*30.42 if m4c_q09_period==8 /*day*/
replace net_profit=.a if m4c_q09_period==7|m4c_q09_period==9|m4c_q09_period==0 /*contract or don't know*/
label var net_profit "Net monthly profit from business" 
	
****************************************************************************************************************************
*HOURLY LABOR earnings             
****************************************************************************************************************************
*NUMBER OF HOURS WORKED LAST WEEK
	/*NOTE THAT SOME WORKERS REPORT HAVING NOT WORKED DURING THE LAST WEEK. THESE OBSERVATIONS ARE CHANGED TO MISSING*/


	mvdecode m4b* m4c*, mv(-99/-44=.)
	mvdecode m4b*, mv(-9/-1=.)
	gen hours =  m4b_q07_1 if m4b_q01_1==m4c_q01_code
	replace hours = m4b_q07_2 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_2  /*For ppl whose main 
																		occupation was listed second*/
	replace hours = m4b_q07_3 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_3  /*For ppl whose main occupation 
																		was listed third*/
	label var hours "Number of hours worked last week in main occupation"	
	
	gen hours_d =  m4b_q06_1 if m4b_q01_1==m4c_q01_code
	replace hours_d = m4b_q06_2 if m4b_q01_1!=m4c_q01_code &  m4c_q01_code==m4b_q01_2  /*For ppl whose main 
																		occupation was listed second*/
	replace hours_d = m4b_q06_3 if m4b_q01_1!=m4c_q01_code & m4c_q01_code==m4b_q01_3  /*For ppl whose main occupation 
																		was listed third*/
	label var hours_d "Average number of hours worked daily in main occupation"																			
	
*HOURLY LABOR earnings 
	/*NOTES: 1. Assume that "last week" was a typical workweek. 
			 2. Use 4.35 as # of weeks in one month, 21.7 as # of week days in a month.
			 3. Assume net profits are not shared with other investors.
			 4. earningss with "other" pay periods have to be computed by hand. Some of these cannot
			   be computed, however, as they do not correspond to time periods per se or are not specified.*/
	mvdecode m4c_q24 m4c_q25 m4c_q26 m4c_q27, mv(-9/-1=.)
	gen     earnings_h = m4c_q24/hours/4.35 if m4c_q25==1   				/*earnings for wage earners, 1 month*/
	replace earnings_h = m4c_q24/hours/2.17 if m4c_q25==2 				/*earnings for wage earners,  2 weeks*/
	replace earnings_h = m4c_q24/hours   if m4c_q25==3 				    /*earnings for wage earners,  1 week*/
	replace earnings_h = m4c_q24/hours_d  if m4c_q25==4     			    /*earnings for wage earners, 1 day*/
	replace earnings_h = m4c_q26/hours/4.35 if m4c_q27==1   				/*earnings for self-employed, 1 month*/
	replace earnings_h = m4c_q26/hours/2.17 if m4c_q27==2 				/*earnings for self-employed,  2 weeks*/
	replace earnings_h = m4c_q26/hours   if m4c_q27==3 				    /*earnings for self-employed,  1 week*/
	replace earnings_h = m4c_q26/hours_d  if m4c_q27==4     			    /*earnings for self-employed, 1 day*/
	replace earnings_h=. 				if m4c_q24<0| m4c_q26<0 			/*Don't report earnings*/
	replace earnings_h=. 				if m4c_q25==9| m4c_q25<0 |m4c_q27==9| m4c_q27<0 /*Don't report pay period*/
	replace earnings_h=. 				if hours==. 						/*Don't have info. on no. of hours*/
	label var earnings_h "Hourly labor earnings" 
	notes earnings_h: earnings for wage earners is net of taxes and benefits. earnings for self-employed is gross.  
	notes earnings_h: Corresponds to main occupation. 



/*Calcuate hourly earnings for people who specify a different pay period*/

if country=="Kenya" {
	replace earnings_h=m4c_q24/(hours_d*2) if m4c_q25==97 & (m4c_q25_other=="2 days" | m4c_q25_other=="Two days" | m4c_q25_other=="weekend")
	replace earnings_h=m4c_q24/(hours_d*3) if m4c_q25==97 & (m4c_q25_other=="3 days" | m4c_q25_other=="For 3 days")
	replace earnings_h=m4c_q24 if m4c_q25==97 & (m4c_q25_other=="hours")
	replace earnings_h=m4c_q26/hours/8.70 if m4c_q27==97 & (m4c_q27_other=="2 months" | m4c_q27_other=="TWO MONTHS" | m4c_q27_other=="two months")
	replace earnings_h= m4c_q26/hours/1.45 if m4c_q27==97 & m4c_q27_other=="3 WEEKS" 
	replace earnings_h=m4c_q26/(hours_d*3) if m4c_q27==97 & (m4c_q27_other=="three days" | m4c_q27_other=="LESS THAN A WEEK MORE THAN TWO")
	replace earnings_h=m4c_q26/(hours_d*2) if m4c_q27==97 & (m4c_q27_other=="After 2 days")
	replace earnings_h= m4c_q26/hours/26.1 if m4c_q27==97 & m4c_q27_other=="6 months period"
	replace earnings_h= m4c_q26/hours/30.45 if m4c_q27==97 & m4c_q27_other=="7 months"
}	

if country=="Macedonia" {
	replace earnings_h=m4c_q24 if m4c_q25==5 & m4c_q25_other=="per hour"
	replace earnings_h=m4c_q24/hours/13.05 if m4c_q25==5 & m4c_q25_other=="three months"
	replace earnings_h=m4c_q24/hours/8.70 if m4c_q25==5 & m4c_q25_other=="two months"
	replace earnings_h=m4c_q26/hours/8.70 if m4c_q27==5 & (m4c_q27_other=="two months" | m4c_q27_other=="eight weeks")
	replace earnings_h=m4c_q26/hours/52.2 if m4c_q27==5 & (m4c_q27_other=="one year")
	replace earnings_h=m4c_q26/(hours_d*2) if m4c_q27==5 & (m4c_q27_other=="two days")
	replace earnings_h=m4c_q26/(hours_d*3) if m4c_q27==5 & (m4c_q27_other=="three days")
}
	
	

if country=="Ghana" {
	replace earnings_h=. if m4c_q24==999999|m4c_q26==999999
	replace earnings_h= m4c_q26/hours/1.45 if m4c_q27_other=="(THREE WEEKS)" | m4c_q27_other=="THREE WEEKS" | m4c_q27_other=="3 WEEKS" /* earnings for self-employed, every three weeks*/
	replace earnings_h= m4c_q26/hours/13.05 if m4c_q27_other=="3 MONTHS" 
	replace earnings_h= m4c_q26/hours/52.2 if m4c_q27_other=="ONE YEAR" | m4c_q27_other=="YEAR" 
	replace earnings_h= m4c_q26/hours/26.1 if m4c_q27_other=="6 MONTHS AGO"
	replace earnings_h= m4c_q26/hours/10.875 if m4c_q27_other=="TWO MONTH, TWO WEEKS" /* Determined as 2 and a half months" */
	/* It is not possible to determine earnings_h for the other periods mentioned for both wage earners
	and self-employed*/
}

if country=="Georgia" {
	replace earnings_h=m4c_q24/hours/4.35 if m4c_q25==5 & m4c_q25_other=="1 month"
	replace earnings_h=m4c_q24/hours/13.05 if m4c_q25==5 & m4c_q25_other=="3 months"
	replace earnings_h=m4c_q24/(hours_d*2) if m4c_q25==5 & m4c_q25_other=="2 days"
	replace earnings_h=m4c_q24/(hours_d*4) if m4c_q25==5 & m4c_q25_other=="4 days"
}

gen ln_earnings_h=log(earnings_h + 0.0000000000000000000001)
label var ln_earnings_h "Log of hourly earnings" 


*UNDEREMPLOYED 
egen total_hours_week= rsum( m4b_q07_1 m4b_q07_2 m4b_q07_3)
gen underemp=1 if m4b_q09==1 & total_hours_week<35
replace underemp=0 if m4b_q09==2 
replace underemp=0 if total_hours_week>=35 & m4b_q09==1 & total_hours_week<.
label define underemp 0 "Not underemployed"  1 "Underemployed", replace 
label values underemp underemp
label var underemp "Underemployed"
notes underemp: Refers to working under 35 hours/week and wanting to work more hours for the same pay.
label var total_hours_week "Total hours worked during the week, all jobs"

*SOURCE OF FUNDS (FOR SELF-EMPLOYED)
recode m4c_q07 (1=1) (2=1) (3=1) (4=1) (5=0) (6=0) (7=0)(8=0) (9=1)  (10=0) (99=.) (-7/-1=.) (-66=0), gen(source_funds)
replace source_funds=0 if source_funds>10 & source_funds<99 
label var source_funds "Source of funds for starting business" 
label define source_funds 1 "Used family money" 0 "Did not use family money", replace
label values source_funds source_funds

if country=="Ghana" | country=="Armenia"{
recode source_funds (-9=0)
}

*SIZE OF BUSINESS AT START
gen business_size=1 if m4c_q08==1
replace business_size=0 if m4c_q08>1 & m4c_q08<.
label var business_size "Size of business at start"
label define business_size 1 "One person" 0 "More than 1 person", replace
label values business_size business_size


**************************************************** END OF LABOR MARKET SECTION ****************************************************


***********************************************************************************************************************************************
*********************************************************     EDUCATION VARIABLES     *********************************************************
***********************************************************************************************************************************************
mvdecode m2*, mv(-77/-44=.)

*ece (don't know's=missing)
gen ece=1 if m2_q01==1
replace ece=0 if m2_q01==2

*certification not awarded by a formal education institution
gen certificate=0 
replace certificate=1 if m2_q17==1 | m2_q05==1

*currently attending
gen current=1 if m2_q19==1
replace current=0 if  m2_q19==2
replace current=0 if m2_q02==2
*dropout
gen dropout=1 if m2_q22==1
replace dropout=0 if m2_q22==2
replace dropout=0 if current==1 /*If currently attending, don't answer this question*/
*interrupt
gen interrupt=1 if m2_q36>=1
replace interrupt=0 if interrupt==. 
*training
gen training=1 if m2_q37==1
replace training=0 if m2_q37==2
*apprenticeship
gen apprenticeship=1 if m2_q39==1
replace apprenticeship=0 if m2_q39==2
*age started first grade
mvdecode m2*, mv(-9/-1=.)
gen late_first_grade=1 if m2_q07>=8 & m2_q07<.
replace late_first_grade=0 if m2_q07<8 & m2_q07>0
label var late_first_grade "Started first grade at age 8 or older"
*type of school attended
gen school_type = 1 if m2_q12==1
replace school_type=2 if m2_q12==2|m2_q12==3
replace school_type=3 if m2_q12==4|m2_q12==5|m2_q12==9 |m2_q12==-9
label define school_type 1 "Public" 2 "Private" 3 "Other"
label values school_type school_type
label var school_type "Type of school attended"  
*Age started school
gen age_start=m2_q07
recode age_start (92=.) (99=.) (-9/-1=.)
label var age_start "Age started first grade" 


****************************************** EDUCATION LEVELS AND FIELD ******************************************
**************************** COUNTRY BY COUNTRY AS MODULE 2 IS COUNTRY-SPECIFIC ********************************

/*** Kenya ***/
if country=="Kenya" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace

		/*LABL: The following are the labels for m2_q08a_1, m2_q08b, m2_q15, 
			01 No level or grade completed (did not complete Primary)
			02 Primary Education - Standards 1-8: EACPE / CPE / KCPE
			03 Post-Primary: Youth Polytechnics Craft Trade Certificate
			04 Secondary - Forms 1-6: EACE, KJSE, KCE, KACE
			05 Secondary - Forms 1-4: EAACE, KCSE
			06 TIVET Post-secondary Certificate
			07 TIVET Post-secondary Diploma
			08 TIVET National Polytechnics Higher Diploma
			09 Primary Teacher Certificate
			10 Teacher Training Diploma
			11 Post-Secondary (not including Teacher Training): Certifi
			12 Post-Secondary (not including Teacher Training): Diploma
			13 University Degree (Bachelor)
			14 Post-Graduate Diploma
			15 Post-Graduate Degree (Masters)
			16 Post-Graduate: Doctorate / PhD
			97 Other

*/

*Highest level completed with vocation distinction (ISCED_v)
recode m2_q08a_1 (1=0) (2=1) (3=4) (4=3) (5=5) (6=4) (7=7) (8=8) (9=8) (10=8) (11=4) (12=7) (13=9) (14=9) (15=9) (16=9) (97=.), gen(ISCED_v)

/* 
Primary Education: Was assumed to be in ISCED 1, but there were cases that may correspond to ISCED 2A, so corrections have been made below to fix it.
Secondary - Forms 1-6: EACE, KJSE, KCE, KACE is an ISCED 2A level
Post-Secondary (not including Teacher Training): Certificate is an ISCED 3B Level
Post-Secondary (not including Teacher Training): Diploma is an ISCED 4A level
*/

*Correct for cases in which a given cycle was not actually completed
	// Note: as Question m2_q08b was not always correctly understood,
	// 		if a respondent reports having completed a cycle in 8B, 
	//		but did not complete all grades of that cycle (in 8A-grade), we will consider that s/he did NOT complete the cycle in question

forvalues x=1/16 {
di "m2_q08a_1==`x'"
	tab m2_q08a_2 m2_q08b if  m2_q08a_1==`x', m nolab
}


*Primary
replace ISCED_v=0 if m2_q08a_1==2 & (m2_q08b==1 & m2_q08a_2<=8)					// less or equal to 8 years and reported primary education, and highest level is no level completed -> highest level is no level completed
replace ISCED_v=0 if m2_q08a_1==2 & (m2_q08b==2 & m2_q08a_2<=5)					// less or equal to 5 years and reported primary education, and highest level is primary education  -> highest level is no level completed
replace ISCED_v=1 if m2_q08a_1==2 & (m2_q08b==2 & m2_q08a_2>=6 & m2_q08a_2<=7)	// between 6 to 8 years and reported primary education, and highest level is primary education  -> highest level is ISCED 1

* Post- Primary: Youth Polytechnics Craft Trade Certificate
replace ISCED_v=0 if m2_q08a_1==3 & (m2_q08b==1 & m2_q08a_2<=3)					// less or equal to 3 years and reported post-primary education, and highest level is no level completed -> highest level is no level completed
replace ISCED_v=3 if m2_q08a_1==3 & (m2_q08b==2 & m2_q08a_2<=3)					// less or equal to 3 years and reported post-primary education, and highest level is primary education -> highest level is ISCED 2A

* Secondary - Forms 1-6 EACE, KJSE, KCE, KACE
replace ISCED_v=0 if m2_q08a_1==4 & (m2_q08b==1 & m2_q08a_2<=6)					// less or equal to 6 years and reported Secondary - Forms 1-6 EACE, KJSE, KCE, KACE, and highest level is no level completed -> highest level is no level completed
replace ISCED_v=1 if m2_q08a_1==4 & (m2_q08b==2 & m2_q08a_2<=4)					// less or equal to 4 years and reported Secondary - Forms 1-6 EACE, KJSE, KCE, KACE, and highest level is primary education -> highest level is ISCED 1
replace ISCED_v=3 if m2_q08a_1==4 & (m2_q08b==2 & m2_q08a_2>4 & m2_q08a_2<=6)	// 5 or 6 years and reported Secondary - Forms 1-6 EACE, KJSE, KCE, KACE, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=1 if m2_q08a_1==4 & (m2_q08b==4 & m2_q08a_2<=1)					// less or equal to 1 year and reported Secondary - Forms 1-6 EACE, KJSE, KCE, KACE, and highest level is secondary education forms 1-6 -> highest level is ISCED 1

* Secondary - Forms 1-4 EAACE, KCSE
replace ISCED_v=3 if m2_q08a_1==5 & (m2_q08b==2 & m2_q08a_2<=4)					// less or equal to 4 years and reported Secondary - Forms 1-4 EAACE, KCSE, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=4 if m2_q08a_1==5 & (m2_q08b==3 & m2_q08a_2<=4)					// less or equal to 4 years and reported Secondary - Forms 1-4 EAACE, KCSE, and highest level is post-primary education -> highest level is ISCED 3C
replace ISCED_v=3 if m2_q08a_1==5 & (m2_q08b==4 & m2_q08a_2<=4)					// less or equal to 4 years and reported Secondary - Forms 1-4 EAACE, KCSE, and highest level is Secondary - Forms 1-6 EACE, KJSE, KCE, KACE -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_1==5 & (m2_q08b==5 & m2_q08a_2<=3)					// less or equal to 3 years and reported Secondary - Forms 1-4 EAACE, KCSE, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 2A

* TIVET - Post Secondary Certificate
replace ISCED_v=3 if m2_q08a_1==6 & (m2_q08b==2 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Certificate, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_1==6 & (m2_q08b==4 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Certificate, and highest level is Secondary - Forms 1-6 EACE, KJSE, KCE, KACE -> highest level is ISCED 2A
replace ISCED_v=5 if m2_q08a_1==6 & (m2_q08b==5 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Certificate, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A

* TIVET - Post Secondary Diploma
replace ISCED_v=3 if m2_q08a_1==7 & (m2_q08b==2 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Diploma, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=4 if m2_q08a_1==7 & (m2_q08b==3 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Diploma, and highest level is post-primary education -> highest level is ISCED 3C
replace ISCED_v=3 if m2_q08a_1==7 & (m2_q08b==4 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Diploma, and highest level is Secondary - Forms 1-6 EACE, KJSE, KCE, KACE -> highest level is ISCED 2A
replace ISCED_v=5 if m2_q08a_1==7 & (m2_q08b==5 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Diploma, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A
replace ISCED_v=4 if m2_q08a_1==7 & (m2_q08b==6 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - Post Secondary Diploma, and highest level is TIVET Post Secondary Certificate -> highest level is ISCED 3B

* TIVET - National Polytechnic Higher Diploma
replace ISCED_v=3 if m2_q08a_1==8 & (m2_q08b==2 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - National Polytechnics Higher Diploma, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=5 if m2_q08a_1==8 & (m2_q08b==5 & m2_q08a_2<=4)					// less or equal to 4 years and reported TIVET - National Polytechnics Higher Diploma, and highest level is Secondary - Forms 1-5 EAACE, KCSE -> highest level is ISCED 3A
replace ISCED_v=5 if m2_q08a_1==8 & (m2_q08b==8 & m2_q08a_2<=3)					// less or equal to 3 years and reported TIVET - National Polytechnics Higher Diploma, and highest level is TIVET - National Polytechnics Higher Diploma -> highest level is ISCED 3A

* Primary Teacher Certificate
replace ISCED_v=3 if m2_q08a_1==9 & (m2_q08b==2 & m2_q08a_2<=2)					// less or equal to 2 years and reported Primary Teacher Certificate, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=7 if m2_q08a_1==9 & (m2_q08b==7 & m2_q08a_2<=2)					// less or equal to 2 years and reported Primary Teacher Certificate, and highest level is TIVET Post Secondary Diploma -> highest level is ISCED 4A
replace ISCED_v=5 if m2_q08a_1==9 & (m2_q08b==9 & m2_q08a_2==1)					// equal to 1 year and reported Primary Teacher Certificate, and highest level is Primary Teacher Certificate -> highest level is ISCED 3A

* Teacher Training Diploma
replace ISCED_v=3 if m2_q08a_1==10 & (m2_q08b==2 & m2_q08a_2<=3)				// less or equal to 3 years and reported Teacher Training Diploma, and highest level is primary education -> highest level is ISCED 2A
replace ISCED_v=5 if m2_q08a_1==10 & (m2_q08b==5 & m2_q08a_2<=3)				// less or equal to 3 years and reported Teacher Training Diploma, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A
replace ISCED_v=5 if m2_q08a_1==10 & (m2_q08b==10 & m2_q08a_2<=2)				// less or equal to 2 years and reported Teacher Training Diploma, and highest level is Teacher Training Diploma -> highest level is ISCED 3A

* Post-Secondary Certificate (not including teacher training)
replace ISCED_v=5 if m2_q08a_1==11 & (m2_q08b==5 & m2_q08a_2<=3)				// less or equal to 3 years and reported Post-Secondary Certificate, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A

* Post-Secondary Diploma (not including teacher training)
replace ISCED_v=4 if m2_q08a_1==12 & (m2_q08b==3 & m2_q08a_2<=3)				// less or equal to 3 years and reported Post-Secondary Diploma, and highest level is Post Primary -> highest level is ISCED 3C
replace ISCED_v=3 if m2_q08a_1==12 & (m2_q08b==4 & m2_q08a_2<=3)				// less or equal to 3 years and reported Post-Secondary Diploma, and highest level is Secondary - Forms 1-6 EACE, KJSE, KCE, KACE-> highest level is ISCED 2A
replace ISCED_v=5 if m2_q08a_1==12 & (m2_q08b==5 & m2_q08a_2<=3)				// less or equal to 3 years and reported Post-Secondary Diploma, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A
replace ISCED_v=4 if m2_q08a_1==12 & (m2_q08b==11 & m2_q08a_2<=3)				// less or equal to 3 years and reported Post-Secondary Diploma, and highest level is Post Secondary Certificate -> highest level is ISCED 3B

* University Degree (Bachelor)
replace ISCED_v=5 if m2_q08a_1==13 & (m2_q08b==5 & m2_q08a_2<=3)				// less or equal to 3 years and reported University Degree, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A
replace ISCED_v=7 if m2_q08a_1==13 & (m2_q08b==7 & m2_q08a_2<=3)				// less or equal to 3 years and reported University Degree, and highest level is TIVET Post-Secondary Diploma -> highest level is ISCED 4A
replace ISCED_v=8 if m2_q08a_1==13 & (m2_q08b==8 & m2_q08a_2<=3)				// less or equal to 3 years and reported University Degree, and highest level is TIVET National Polytechnic Higher Diploma -> highest level is ISCED 5B
replace ISCED_v=8 if m2_q08a_1==13 & (m2_q08b==9 & m2_q08a_2<=3)				// less or equal to 3 years and reported University Degree, and highest level is Primary Teacher Certificate -> highest level is ISCED 5B
replace ISCED_v=7 if m2_q08a_1==13 & (m2_q08b==12 & m2_q08a_2<=4)				// less or equal to 4 years and reported University Degree, and highest level is University Degree -> highest level is ISCED 4A
replace ISCED_v=5 if m2_q08a_1==13 & (m2_q08b==13 & m2_q08a_2<=3)				// less or equal to 3 years and reported University Degree, and highest level is University Degree -> highest level is ISCED 3A

* Post- Graduate Diploma
replace ISCED_v=5 if m2_q08a_1==14 & (m2_q08b==5 & m2_q08a_2<=2)				// less or equal to 2 years and reported Post-Graduate Diploma, and highest level is Secondary - Forms 1-4 EAACE, KCSE -> highest level is ISCED 3A

assert ISCED_v==. if m2_q02==2																												
replace ISCED_v=0 if m2_q02==2  							 /*Did not attend school*/

recode m2_q15 (1=0) (2=1) (3=4) (4=3) (5=5) (6=4) (7=7) (8=8) (9=8) (10=8) (11=4) (12=7) (13=9) (14=9) (15=9) (16=9) (97=.), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<.		/* Use m2_q15 "Other certificate or diploma?" to correct highest level of edcuation completed if relevant*/


*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=5), gen(ISCED)


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if m2_q08a_1==13 /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08a_1==14 | m2_q08a_1==15 /*Post graduate diploma and Master's degree*/
replace ISCED_p=8 if m2_q08a_1==16 /*PhD degree*/ 
replace ISCED_p=9 if m2_q08a_1<. & ISCED_p==.
replace ISCED_p=10 if m2_q08a_1==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*current attending level
recode m2_q20_1 (1=0) (2=1) (3=4) (4=3) (5=5) (6=4) (7=7) (8=8) (9=8) (10=8) (11=4) (12=7) (13=9) (14=9) (15=9) (16=9) (97=.), gen(current_ISCED_v) 
recode m2_q20_1 (1=0) (2=2) (3=3) (4=2) (5=3) (6=3) (7=4) (8=5) (9=5) (10=5) (11=3) (12=4) (13=6) (14=7) (15=7) (16=8) (97=.), gen(current_ISCED_p)
recode m2_q20_1 (1=0) (2=2) (3=3) (4=3) (5=3) (6=3) (7=4) (8=5) (9=5) (10=5) (11=3) (12=4) (13=5) (14=5) (15=5) (16=6) (97=.), gen(current_ISCED)

*level before dropout
recode m2_q24_1 (1=0) (2=1) (3=4) (4=3) (5=5) (6=4) (7=7) (8=8) (9=8) (10=8) (11=4) (12=7) (13=9) (14=9) (15=9) (16=9) (97=.), gen(dropout_ISCED_v) 
recode m2_q24_1 (1=0) (2=2) (3=3) (4=2) (5=3) (6=3) (7=4) (8=5) (9=5) (10=5) (11=3) (12=4) (13=6) (14=7) (15=7) (16=8) (97=.), gen(dropout_ISCED_p)
recode m2_q24_1 (1=0) (2=2) (3=3) (4=3) (5=3) (6=3) (7=4) (8=5) (9=5) (10=5) (11=3) (12=4) (13=5) (14=5) (15=5) (16=6) (97=.), gen(dropout_ISCED)


* NUMBER OF YEARS OF EDUCATION ACTUALLY COMPLETED (TR)
gen years_educ_act=0 if m2_q02==2 											// No formal education
replace years_educ_act=0 if m2_q08a_1==1									// No grade completed
replace years_educ_act=m2_q08a_2 if m2_q08a_1==2							// Primary 
replace years_educ_act=8+m2_q08a_2 if m2_q08a_1==3							// Post Primary: Youth Polytechnics Craft
	notes: Individuals who took do this program are assumed to come from primary education standards 1 to 8. 
replace years_educ_act=6+m2_q08a_2 if m2_q08a_1==4							// Secondary - Forms 1-6: EACE, KJSE, KCE, KACE
	notes: Individuals who took do this program are assumed to come from primary education standards 1 to 6. 
replace years_educ_act=8+m2_q08a_2 if m2_q08a_1==5							// Secondary - Forms 1-4: EAACE, KCSE
	notes: Individuals who took do this program are assumed to come from primary education standards 1 to 8. 
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==6							// TIVET Post-Secondary Certificate
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==7							// TIVET Post-Secondary Diploma
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==8							// TIVET National Polytechnics Higher Diploma
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==9							// Primary Teacher Certificate
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==10						// Teacher Training Diploma
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==11						// Post-Secondary Certificate
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==12						// Post-Secondary Diploma
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=12+m2_q08a_2 if m2_q08a_1==13						// University Degree
	notes: Individuals who took do this program are assumed to come from secondary - forms 1-4 EAACE, KCSE. 	
replace years_educ_act=16+m2_q08a_2 if m2_q08a_1==14						// Post-Graduate Diploma
	notes: Individuals who took do this program are assumed to come from 4 year bachelor degree. 	
replace years_educ_act=16+m2_q08a_2 if m2_q08a_1==15						// Post-Graduate Masters
	notes: Individuals who took do this program are assumed to come from 4 year bachelor degree. 						
replace years_educ_act=18+m2_q08a_2 if m2_q08a_1==16						// Doctorate
	notes: Individuals who took do this program are assumed to come from 2 year Masters degree. 
	
* Correct for m2_q15 - i.e. if a higher certificate or diploma was obtained
replace years_educ_act=10 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==3				//Post Primary: Youth Polytechnics Craft 
replace years_educ_act=12 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==5				// Secondary - Forms 1-4: EAACE, KCSE
replace years_educ_act=14 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==7				// TIVET Post-Secondary Diploma
replace years_educ_act=16 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==8				// TIVET National Polytechnics Higher Diploma
replace years_educ_act=14 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==9				// Primary Teacher Certificate
replace years_educ_act=15 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==10				// Teacher Training Diploma
replace years_educ_act=13 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==11				// Post-Secondary Certificate
replace years_educ_act=14 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==12				// Post-Secondary Diploma
replace years_educ_act=16 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==13				// University Degree
replace years_educ_act=17 if m2_q15>m2_q08a_1 & m2_q15!=. & m2_q08a_1!=. & m2_q15==14				// Post-Graduate Diploma

label var years_educ_act "Years of education actually completed"


* NUMBER OF YEARS OF EDUCATION CORRESPONDING TO THE HIGHEST LEVEL COMPLETED (TR)
gen years_educ=0 if ISCED_p==0							// No formal education or less than primary
replace years_educ=6 if ISCED_p==1 						// Primary completed
replace years_educ=6+2 if ISCED_p==2 					// Lower Secondary completed
replace years_educ=6+2+4 if ISCED_p==3 					// Upper Secondary completed
replace years_educ=6+2+4+2 if ISCED_p==4 				// Post Secondary Technical/Vocational
replace years_educ=6+2+4+3 if ISCED_p==5 				// Post Secondary Technical/Vocational
replace years_educ=6+2+4+4 if ISCED_p==6 				// University First Degree - Bachelor
replace years_educ=6+2+4+4+2 if ISCED_p==7 				// University Second Degree - Master
replace years_educ=6+2+4+4+2+4 if ISCED_p==8 			// PhD
/* Following the years of duration stated in the ISCED 97 mapping for Kenya
assumptions:	1. Those in ISCED_p==5 can take either 2,3 or 4 years, the middle point was chosen. 
				2. Those in ISCED_p==6 can take either 4 or 5-6 years, a 4 year program was assumed. 
		
*/


*FIELD OF EDUCATION
gen highest=m2_q08a_1
gen highest2=m2_q15
gen hgsteduc=max(highest, highest2)
gen hgstcurrent=m2_q20_1
gen hgstdrop=m2_q24_1

*Highest field
gen highest_field_1=m2_q09_1 
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q18 if m2_q18~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=m2_q09_2
replace highest_field_2=. if hgsteduc>highest & hgsteduc~=.

drop highest highest2 hgsteduc

*current attending field 
gen current_field=m2_q21 

*field before dropout
gen dropout_field=m2_q25 

*training field
gen training_field_1=m2_q38_1 
gen training_field_2=m2_q38_2


*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q24_1 (1=0) (2=2) (3=3) (4=3) (5=3) (6=3) (7=4) (8=5) (9=5) (10=5) (11=3) (12=4) (13=5) (14=5) (15=5) (16=6) (97=.), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q24_1==99 
label var ISCED_needed "Education level need for the job"
	notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13>=3 & m2_q13<.


}

/**** END OF KENYA ****/


/*** Macedonia ***/
if country=="Macedonia" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace


	/*LABL: The following are the labels for m2_q08, m2_q15, m2_q21, m2_q26
		Before 2008
		02 Low primary
		03 High primary
		04 2 year Secondary Vocational training
		05 3 year Secondary Vocational training
		06 4 year Secondary Vocational training
		07 Gymnasium
		08 Islamic or Orthodox secondary school
		09 Post-secondary specialist vocational ed
		10 Professional two-yr college (up to 2.5
		11 University bachelor program
		12 Bachelor - medical, pharmacy, stomatolo
		13 Specialization - medical, pharmacy, sto
		14 Masters program
		15 One yr specialist diploma (Bachelor pre
		16 Doctorate
		After 2008
		22 Low primary
		23 Upper primary
		24 2 year Secondary Vocational training
		25 3 year Secondary Vocational training
		26 4 year Secondary Vocational training
		27 Gymnasium
		28 Islamic or Orthodox secondary school
		31 University bachelor program
		32 Bachelor - medical, pharmacy, stomatolo
		33 Specialization - medical, pharmacy, sto
		34 Masters program
		36 Doctorate

	*/

* Highest level completed with vocation distinction (ISCED_v)
recode m2_q08a_l (1=0) (2=1) (3=3) (4=4) (5=4) (6=4) (7=5) (8=5) (9=6) (10=8) (11=9) (12=9) (13=9) (14=9) (15=9) (16=9) (22=1) (23=3) (24=4) (25=4) (26=4) (27=5) (28=5) (29=6) (31=9) (32=9) (33=9) (34=9) (35=9) (36=9), gen(ISCED_v)

*Correct for cases in which a given cycle was not actually completed
	// Note: as Question m2_q08b was not always correctly understood,
	// 		if a respondent reports having completed a cycle in 8B, 
	//		but did not complete all grades of that cycle (in 8A-grade), we will consider that s/he did NOT complete the cycle in question

forvalues x=1/36 {
di "m2_q08a_l==`x'"
	tab m2_q08a_g m2_q08b if  m2_q08a_l==`x', missing nolab
}

* Before 2008	
* Low primary
replace ISCED_v=0 if m2_q08a_l==2 & (m2_q08b==1 & m2_q08a_g<4)		// less than 4 years and reported low primary education, and highest level completed is no level completed -> highest level completed no level 
replace ISCED_v=0 if m2_q08a_l==2 & (m2_q08b==2 & m2_q08a_g<4)		// less than 4 years and reported low primary education, and highest level completed is low primary completed -> highest level completed no level 

* High primary
replace ISCED_v=0 if m2_q08a_l==3 & (m2_q08b==1 & m2_q08a_g<=8) 	// less than or equal to 8 years and reported high primary, and highest level completed is no level completed -> highest level completed no level
replace ISCED_v=1 if m2_q08a_l==3 & (m2_q08b==2 & m2_q08a_g<=8) 	// less than or equal to 8 years and reported high primary, and highest level completed is low primary -> highest level completed ISCED 1 
replace ISCED_v=1 if m2_q08a_l==3 & (m2_q08b==3 & m2_q08a_g<8) 		// less than 8 years and reported high primary, and highest level completed is high primary -> highest level completed ISCED 1 

* 2 year Secondary Vocational Educ.
replace ISCED_v=3 if m2_q08a_l==4 & (m2_q08b==3 & m2_q08a_g==1) 	// Equal to 1 years and reported 2 year secondary vocational education, and highest level completed is high primary -> highest level is ISCED 2A

* 3 year Secondary Vocational Educ.
replace ISCED_v=3 if m2_q08a_l==5 & (m2_q08b==3 & m2_q08a_g<=2) 	// less than or equal to 2 years and reported 3 year secondary vocational education, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==5 & (m2_q08b==5 & m2_q08a_g<=2) 	// less than or equal to 2 years and reported 3 year secondary vocational education, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==5 & (m2_q08b==6 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported 3 year secondary vocational education, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 2A

* 4 year Secondary Vocational Educ.
replace ISCED_v=3 if m2_q08a_l==6 & (m2_q08b==3 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported 4 year secondary vocational education, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==6 & (m2_q08b==5 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported 4 year secondary vocational education, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=3 if m2_q08a_l==6 & (m2_q08b==6 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported 4 year secondary vocational education, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==6 & (m2_q08b==7 & m2_q08a_g<=4) 	// less than or equal to 4 years and reported 4 year secondary vocational education, and highest level completed is Gymnasium -> highest level is ISCED 2A

* Gymnasium 
replace ISCED_v=3 if m2_q08a_l==7 & (m2_q08b==3 & m2_q08a_g<=4) 	// less than or equal to 4 years and reported gymnasium, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=4 if m2_q08a_l==7 & (m2_q08b==5 & m2_q08a_g==3) 	// equal to 3 years and reported gymnasium, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=4 if m2_q08a_l==7 & (m2_q08b==6 & m2_q08a_g==4) 	// equal to 4 years and reported gymnasium, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=3 if m2_q08a_l==7 & (m2_q08b==7 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported gymnasium, and highest level completed is gymnasium -> highest level is ISCED 2A

* Islamic or Orthodox Secondary School
replace ISCED_v=3 if m2_q08a_l==8 & (m2_q08b==3 & m2_q08a_g<=5) 	// less than or equal to 5 years and reported islamic or orthodox secondary school, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==8 & (m2_q08b==8 & m2_q08a_g<=4) 	// less than or equal to 4 years and reported islamic or orthodox secondary school, and highest level completed is islamic or orthodox secondary certificate -> highest level is ISCED 2A

* Post-secondary specialist vocational education
/* No cases to correct*/

* Professional 2 year college
replace ISCED_v=4 if m2_q08a_l==10 & (m2_q08b==5 & m2_q08a_g==1) 	// equal to 1 year and reported professional 2 year college, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=4 if m2_q08a_l==10 & (m2_q08b==6 & m2_q08a_g<=2) 	// less than or equal to 2 years and reported professional 2 year college, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=5 if m2_q08a_l==10 & (m2_q08b==10 & m2_q08a_g==1) 	// equal to 1 year and reported professional 2 year college, and highest level completed is professional two year college -> highest level is ISCED 3A

* University bachelor program
replace ISCED_v=4 if m2_q08a_l==11 & (m2_q08b==5 & m2_q08a_g==1) 	// equal to 1 years and reported university bachelor program, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=4 if m2_q08a_l==11 & (m2_q08b==6 & m2_q08a_g<=6) 	// equal to 6 years and reported university bachelor program, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=5 if m2_q08a_l==11 & (m2_q08b==7 & m2_q08a_g<=6) 	// equal to 6 years and reported university bachelor program, and highest level completed is gymnasium -> highest level is ISCED 3A
replace ISCED_v=5 if m2_q08a_l==11 & (m2_q08b==8 & m2_q08a_g<=6) 	// equal to 6 years and reported university bachelor program, and highest level completed is islamic or orthodox secondary school -> highest level is ISCED 3A
replace ISCED_v=8 if m2_q08a_l==11 & (m2_q08b==10 & m2_q08a_g<=6) 	// equal to 6 years and reported university bachelor program, and highest level completed is professional two year college -> highest level is ISCED 5B
replace ISCED_v=5 if m2_q08a_l==11 & (m2_q08b==11 & m2_q08a_g<=3) 	// equal to 3 years and reported university bachelor program, and highest level completed is university bachelor program -> highest level is ISCED 3A

* Bachelor - medical, pharmacy, stomatology
replace ISCED_v=4 if m2_q08a_l==12 & (m2_q08b==6 & m2_q08a_g<=6) 	// less than or equal to 6 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=5 if m2_q08a_l==12 & (m2_q08b==7 & m2_q08a_g<=6) 	// less than or equal to 6 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is gymnasium -> highest level is ISCED 3A
replace ISCED_v=5 if m2_q08a_l==12 & (m2_q08b==12 & m2_q08a_g<=5) 	// less than or equal to 5 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is bachelor degree - medical, pharmacy, stomatology -> highest level is ISCED 3A

* Specialization - medical, pharmacy, stomatology
replace ISCED_v=4 if m2_q08a_l==13 & (m2_q08b==6 & m2_q08a_g<=5) 	// less than or equal to 5 years and reported specializtion - medical, pharmacy, stomatology, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C

* Masters
/* No cases to correct*/

* One yr specialist diploma
/* No cases to correct*/

* Doctorate
replace ISCED_v=8 if m2_q08a_l==16 & (m2_q08b==10 & m2_q08a_g==3) 	// equal to 3 years and reported doctorate, and highest level completed is professional 2 year college -> highest level is ISCED 5B

* After 2008	
* Low primary
replace ISCED_v=0 if m2_q08a_l==22 & (m2_q08b==1 & m2_q08a_g<=6)	// less than or equal to 6 years and reported low primary education, and highest level completed is no level completed -> highest level completed no level 

* High primary
replace ISCED_v=0 if m2_q08a_l==23 & (m2_q08b==1 & m2_q08a_g<=9) 	// less than or equal to 9 years and reported high primary, and highest level completed is no level completed -> highest level completed no level
replace ISCED_v=1 if m2_q08a_l==23 & (m2_q08b==2 & m2_q08a_g<=9) 	// less than or equal to 9 years and reported high primary, and highest level completed is low primary -> highest level completed ISCED 1 

* 2 year Secondary Vocational Educ.
replace ISCED_v=3 if m2_q08a_l==24 & (m2_q08b==3 & m2_q08a_g==1) 	// Equal to 1 years and reported 2 year secondary vocational education, and highest level completed is high primary -> highest level is ISCED 2A

* 3 year Secondary Vocational Educ.
replace ISCED_v=3 if m2_q08a_l==25 & (m2_q08b==3 & m2_q08a_g<=2) 	// less than or equal to 2 years and reported 3 year secondary vocational education, and highest level completed is high primary -> highest level is ISCED 2A

* 4 year Secondary Vocational Educ.
replace ISCED_v=3 if m2_q08a_l==26 & (m2_q08b==3 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported 4 year secondary vocational education, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==26 & (m2_q08b==6 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported 4 year secondary vocational education, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 2A

* Gymnasium 
replace ISCED_v=3 if m2_q08a_l==27 & (m2_q08b==3 & m2_q08a_g<=4) 	// less than or equal to 4 years and reported gymnasium, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=4 if m2_q08a_l==27 & (m2_q08b==5 & m2_q08a_g==3) 	// equal to 3 years and reported gymnasium, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 3C

* Islamic or Orthodox Secondary School
replace ISCED_v=3 if m2_q08a_l==28 & (m2_q08b==3 & m2_q08a_g<=4) 	// less than or equal to 4 years and reported islamic or orthodox secondary school, and highest level completed is high primary -> highest level is ISCED 2A
replace ISCED_v=3 if m2_q08a_l==28 & (m2_q08b==8 & m2_q08a_g<=4) 	// less than or equal to 4 years and reported islamic or orthodox secondary school, and highest level completed is high Islamic & Orhtodox secondary -> highest level is ISCED 2A

* Post-secondary specialist vocational education
/* No cases to correct*/

* University bachelor program
replace ISCED_v=4 if m2_q08a_l==31 & (m2_q08b==6 & m2_q08a_g<=4) 	// equal to 4 years and reported university bachelor program, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=5 if m2_q08a_l==31 & (m2_q08b==7 & m2_q08a_g<=4) 	// equal to 4 years and reported university bachelor program, and highest level completed is gymnasium -> highest level is ISCED 3A
replace ISCED_v=5 if m2_q08a_l==31 & (m2_q08b==8 & m2_q08a_g<=4) 	// equal to 4 years and reported university bachelor program, and highest level completed is islamic or orthodox secondary school -> highest level is ISCED 3A

* Bachelor - medical, pharmacy, stomatology
replace ISCED_v=4 if m2_q08a_l==32 & (m2_q08b==5 & m2_q08a_g<=6) 	// less than or equal to 6 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is 3 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=4 if m2_q08a_l==32 & (m2_q08b==6 & m2_q08a_g<=6) 	// less than or equal to 6 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is 4 year secondary vocational training -> highest level is ISCED 3C
replace ISCED_v=5 if m2_q08a_l==32 & (m2_q08b==7 & m2_q08a_g<=6) 	// less than or equal to 6 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is gymnasium -> highest level is ISCED 3A
replace ISCED_v=5 if m2_q08a_l==32 & (m2_q08b==12 & m2_q08a_g<=3) 	// less than or equal to 3 years and reported bachelor - medical, pharmacy, stomatology, and highest level completed is bachelor - medical, pharmacy, stomatology-> highest level is ISCED 3A

* Specialization - medical, pharmacy, stomatology
/* No cases to correct*/

* Masters
/* No cases to correct*/

* One yr specialist diploma
/* No cases to correct*/

* Doctorate
/* No cases to correct*/

																									
replace ISCED_v=0 if m2_q02==2  							 /*Did not attend school*/

recode m2_q15 (1=0) (2=1) (3=3) (4=4) (5=4) (6=4) (7=5) (8=5) (9=6) (10=8) (11=9) (12=9) (13=9) (14=9) (15=9) (16=9) (22=1) (23=3) (24=4) (25=4) (26=4) (27=5) (28=5) (29=6) (31=9) (32=9) (33=9) (34=9) (35=9) (36=9), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<.		/* Use m2_q15 "Other certificate or diploma?" to correct highest level of edcuation completed if relevant*/


*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED)


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.), gen(ISCED_p) 
replace ISCED_p=6 if (m2_q08a_l==11 | m2_q08a_l==12 | m2_q08a_l==31 | m2_q08a_l==32) & ISCED_p==.  /*Bachelor's degree*/
replace ISCED_p=7 if (m2_q08a_l==13 | m2_q08a_l==14 | m2_q08a_l==15 | m2_q08a_l==33 | m2_q08a_l==34) & ISCED_p==. /* Master's Degree*/
	replace ISCED_p=6 if m2_q08a_l==13 & (m2_q08b==12 & m2_q08a_g==5) /* These respondents reported having being at specialist level with highest diploma of bachelors*/
	replace ISCED_p=6 if m2_q08a_l==14 & (m2_q08b==11 & m2_q08a_g==1) /* These respondents reported having being at masters level with highest diploma of bachelors*/
	replace ISCED_p=6 if m2_q08a_l==33 & (m2_q08b==12 & m2_q08a_g<=5) /* These respondents reported having being at masters level with highest diploma of bachelors*/
	replace ISCED_p=6 if m2_q08a_l==34 & (m2_q08b==11 & m2_q08a_g==1) /* These respondents reported having being at masters level with highest diploma of bachelors*/
replace ISCED_p=8 if (m2_q08a_l==16 | m2_q08a_l==36) & ISCED_p==. /*PhD degree*/
	replace ISCED_p=6 if m2_q08a_l==16 & (m2_q08b==11 & m2_q08a_g==3) /* These respondents reported having being at doctorate level with highest diploma of bachelors*/
	replace ISCED_p=7 if m2_q08a_l==36 & (m2_q08b==14 & m2_q08a_g==1) /* These respondents reported having being at doctorate level with highest diploma of masters*/
replace ISCED_p=9 if m2_q08a_l<. & ISCED_p==.
replace ISCED_p=10 if m2_q08a_l==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*current attending level
recode m2_q20_l (1=0) (2=1) (3=3) (4=4) (5=4) (6=4) (7=5) (8=5) (9=6) (10=8) (11=9) (12=9) (13=9) (14=9) (15=9) (16=9) (22=1) (23=3) (24=4) (25=4) (26=4) (27=5) (28=5) (29=6) (31=9) (32=9) (33=9) (34=9) (35=9) (36=9), gen(current_ISCED_v) 
recode m2_q20_l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=3) (8=3) (9=4) (10=5) (11=6) (12=6) (13=7) (14=7) (15=7) (16=8) (22=1) (23=2) (24=3) (25=3) (26=3) (27=3) (28=3) (29=4) (31=6) (32=6) (33=7) (34=7) (35=7) (36=8), gen(current_ISCED_p)
recode m2_q20_l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=3) (8=3) (9=4) (10=5) (11=5) (12=5) (13=5) (14=5) (15=5) (16=6) (22=1) (23=2) (24=3) (25=3) (26=3) (27=3) (28=3) (29=4) (31=5) (32=5) (33=5) (34=5) (35=5) (36=6), gen(current_ISCED)

*level before dropout
recode m2_q24_l (1=0) (2=1) (3=3) (4=4) (5=4) (6=4) (7=5) (8=5) (9=6) (10=8) (11=9) (12=9) (13=9) (14=9) (15=9) (16=9) (22=1) (23=3) (24=4) (25=4) (26=4) (27=5) (28=5) (29=6) (31=9) (32=9) (33=9) (34=9) (35=9) (36=9), gen(dropout_ISCED_v) 
recode m2_q24_l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=3) (8=3) (9=4) (10=5) (11=6) (12=6) (13=7) (14=7) (15=7) (16=8) (22=1) (23=2) (24=3) (25=3) (26=3) (27=3) (28=3) (29=4) (31=6) (32=6) (33=7) (34=7) (35=7) (36=8), gen(dropout_ISCED_p)
recode m2_q24_l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=3) (8=3) (9=4) (10=5) (11=5) (12=5) (13=5) (14=5) (15=5) (16=6) (22=1) (23=2) (24=3) (25=3) (26=3) (27=3) (28=3) (29=4) (31=5) (32=5) (33=5) (34=5) (35=5) (36=6), gen(dropout_ISCED)


* NUMBER OF YEARS OF EDUCATION ACTUALLY COMPLETED (TR)
* Before 2008
gen years_educ_act=0 if m2_q02==2 											// No formal education
replace years_educ_act=0 if m2_q08a_l==1									// No grade completed
replace years_educ_act=m2_q08a_g if m2_q08a_l==2 							// Low Primary school
replace years_educ_act=m2_q08a_g if m2_q08a_l==3							// High Primary School
replace years_educ_act=8+m2_q08a_g if m2_q08a_l==4							// 2 year secondary vocational training
replace years_educ_act=8+m2_q08a_g if m2_q08a_l==5							// 3 year secondary vocational training
replace years_educ_act=8+m2_q08a_g if m2_q08a_l==6							// 4 year secondary vocational training
replace years_educ_act=8+m2_q08a_g if m2_q08a_l==7							// Gymnasium
replace years_educ_act=8+m2_q08a_g if m2_q08a_l==8							// Islamic or Orthodox secondary school
replace years_educ_act=12+m2_q08a_g if m2_q08a_l==9							// Post-secondary specialist vocational education
	notes: individual who reported being in post-secondary specialist vocational education, assumption is that these are years in addition to secondary (gymnasium, or islamic or orthodox secondary school)
replace years_educ_act=12+m2_q08a_g if m2_q08a_l==10						// Professional two year college
	notes: individual who reported being in professional two year college, assumption is that these are years in addition to secondary (gymnasium, or islamic or orthodox secondary school)
replace years_educ_act=12+m2_q08a_g if m2_q08a_l==11						// University bachelor program
	notes: individual who reported being in university bachelor program, assumption is that these are years in addition to secondary (gymnasium, or islamic or orthodox secondary school)
replace years_educ_act=12+m2_q08a_g if m2_q08a_l==12						// Bachelor - medical, pharmacy, stomatology 
	notes: individual who reported being in bachelor - medical, pharmacy, stomatology, assumption is that these are years in addition to secondary (gymnasium, or islamic or orthodox secondary school)
replace years_educ_act=18+m2_q08a_g if m2_q08a_l==13						// Specialist - medical, pharmacy, stomatology 
	notes: individual who reported being in specialist- medical, pharmacy, stomatology, assumption is that these are years in addition to bachelor - medical, pharmacist, stomatology
replace years_educ_act=18+m2_q08a_g if m2_q08a_l==14						// Master
	notes: individual who reported being in master, assumption is that these are years in addition to university bachelor program
replace years_educ_act=18+m2_q08a_g if m2_q08a_l==15						// One year specialist diploma
	notes: individual who reported being in one year specialist diploma, assumption is that these are years in addition to university bachelor program
replace years_educ_act=20+m2_q08a_g if m2_q08a_l==16						// doctorate
	notes: individual who reported being in doctorate, assumption is that these are years in addition to masters

*After 2008
replace years_educ_act=m2_q08a_g if m2_q08a_l==22 							// Low Primary school
replace years_educ_act=m2_q08a_g if m2_q08a_l==23							// High Primary School
replace years_educ_act=9+m2_q08a_g if m2_q08a_l==24							// 2 year secondary vocational training
replace years_educ_act=9+m2_q08a_g if m2_q08a_l==25							// 3 year secondary vocational training
replace years_educ_act=9+m2_q08a_g if m2_q08a_l==26							// 4 year secondary vocational training
replace years_educ_act=9+m2_q08a_g if m2_q08a_l==27							// Gymnasium
replace years_educ_act=9+m2_q08a_g if m2_q08a_l==28							// Islamic or Orthodox secondary school
replace years_educ_act=13+m2_q08a_g if m2_q08a_l==29							// Post-secondary specialist vocational education
	notes: individual who reported being in post-secondary specialist vocational education, assumption is that these are years in addition to secondary (gymnasium, or islamic or orthodox secondary school)
replace years_educ_act=13+m2_q08a_g if m2_q08a_l==31						// University bachelor program
	notes: individual who reported being in university bachelor program, assumption is that these are years in addition to secondary (gymnasium)
replace years_educ_act=13+m2_q08a_g if m2_q08a_l==32						// Bachelor - medical, pharmacy, stomatology 
	notes: individual who reported being in bachelor - medical, pharmacy, stomatology, assumption is that these are years in addition to secondary (gymnasium)
replace years_educ_act=19+m2_q08a_g if m2_q08a_l==33						// Specialist - medical, pharmacy, stomatology 
	notes: individual who reported being in specialist- medical, pharmacy, stomatology, assumption is that these are years in addition to bachelor - medical, pharmacist, stomatology
replace years_educ_act=17+m2_q08a_g if m2_q08a_l==34						// Master
	notes: individual who reported being in master, assumption is that these are years in addition to university bachelor program
replace years_educ_act=17+m2_q08a_g if m2_q08a_l==35						// One year specialist diploma
	notes: individual who reported being in one year specialist diploma, assumption is that these are years in addition to university bachelor program
replace years_educ_act=19+m2_q08a_g if m2_q08a_l==16						// doctorate
	notes: individual who reported being in doctorate, assumption is that these are years in addition to masters
		
			
	

* Correct for m2_q15 - i.e. if a higher certificate or diploma was obtained
/* Based on assumptions from above*/
replace years_educ_act=10 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==4	// 2 year secondary vocational training
replace years_educ_act=11 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==5	// 3 year secondary vocational training
replace years_educ_act=12 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==6	// 4 year secondary vocational training
replace years_educ_act=12 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==7	// Gymnasium 
replace years_educ_act=13 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==8	// Post Secondary Specialist vocational
replace years_educ_act=18 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==9	// Bachelor Degreee
replace years_educ_act=19 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==9	// One year Specialist
replace years_educ_act=23 if (m2_q15>m2_q08a_l) & m2_q15!=. & m2_q08a_l!=. & m2_q15==9	// Doctorate


label var years_educ_act "Years of education actually completed"


* NUMBER OF YEARS OF EDUCATION CORRESPONDING TO THE HIGHEST LEVEL COMPLETED (TR)
gen years_educ=0 if ISCED_p==0					// No formal education or less than primary
replace years_educ=4 if ISCED_p==1 				// Primary completed
replace years_educ=8 if ISCED_p==2 				// Lower Secondary completed
replace years_educ=12 if ISCED_p==3 			// Upper Secondary completed
replace years_educ=13 if ISCED_p==4 			// Post Secondary Specialist Technical/Vocational
replace years_educ=14 if ISCED_p==5 			// 2 year professional
replace years_educ=18 if ISCED_p==6 			// University First Degree - Bachelor
replace years_educ=20 if ISCED_p==7 			// University Second Degree - Master
replace years_educ=23 if ISCED_p==8 			// PhD


*FIELD OF EDUCATION
gen highest=m2_q08a_l
gen highest2=m2_q15
gen hgsteduc=max(highest, highest2)
gen hgstcurrent=m2_q20_l
gen hgstdrop=m2_q24_l

*Highest field
gen highest_field_1=m2_q09_1 
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q18 if m2_q18~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=m2_q09_2
replace highest_field_2=. if hgsteduc>highest & hgsteduc~=.

drop highest highest2 hgsteduc

*current attending field 
gen current_field=m2_q21 

*field before dropout
gen dropout_field=m2_q25 

*training field
gen training_field_1=m2_q38_1 
gen training_field_2=m2_q38_2


*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q24 (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=3) (8=3) (9=4) (10=5) (11=5) (12=5) (13=5) (14=5) (15=5) (16=6), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q24==-9
label var ISCED_needed "Education level need for the job"
	notes ISCED_needed: Corresponds to main job. 
	

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13>=3 & m2_q13<.

}

/**** END OF MACEDONIA ****/

/*** Georgia ***/
if country=="Georgia" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace


	/*LABL: The following are the labels for m2_q08, m2_q15, m2_q21, m2_q26
			01 NO GRADE COMPLETED (NONE OR < ISCED 1)
			02 PRIMARY EDUCATION (ISCED 1)
			03 BASIC EDUCATION (ISCED 2A)
			04 GENERAL SECONDARY EDUCATION (ISCED 3A)
			05 SECONDARY EDUCATION - VOCATIONAL (ISCED 3C)
			06 VOCATIONAL LEVEL 4 & 5 (ISCED 5B)
			07 BACHELOR (ISCED 5A)
			08 BACHELOR (ISCED 5A)
			09 MASTERS (ISCED 5A)
			10 DOCTORATE(ISCED 6)
*/

* Highest level completed with vocation distinction (ISCED_v)
recode m2_q08a (1=0) (2=1) (3=3) (4=5) (5=4) (6=8) (7=9) (8=9) (9=9) (10=9), gen(ISCED_v)

*Correct for cases in which a given cycle was not actually completed
	// Note: as Question m2_q08b was not always correctly understood,
	// 		if a respondent reports having completed a cycle in 8B, 
	//		but did not complete all grades of that cycle (in 8A-grade), we will consider that s/he did NOT complete the cycle in question

forvalues x=1/10 {
di "m2_q08a==`x'"
	tab m2_q08b m2_q08b_1 if  m2_q08a==`x', missing nolab
}
	
*Primary or less
replace ISCED_v=0 if m2_q08a==2 & (m2_q08b_1==2 & m2_q08b<6)				// less than 6 years and reported primary education, and highest level completed is primary education -> highest level completed primary
replace ISCED_v=5 if m2_q08a==2 & (m2_q08b_1==4 & m2_q08b>6 & m2_q08b<.)	 // Special case: Reported being in primary education, but level and years correspond to General Secondary Education. 
replace ISCED_v=4 if m2_q08a==2 & (m2_q08b_1==5 & m2_q08b>6 & m2_q08b<.)	 // Special case: Reported being in primary education, but level and years correspond to Secondary Education - vocational. 

*Basic Education
replace ISCED_v=1 if m2_q08a==3 & (m2_q08b_1==2 & m2_q08b<=9) 		// less than or equal to 9 years and highest level completed is primary -> highest level completed is primary
replace ISCED_v=1 if m2_q08a==3 & (m2_q08b_1==3 & m2_q08b<9) 		// less than to 9 years although reported highest level completed as basic education  -> highest level completed is primary
replace ISCED_v=. if m2_q08a==3 & (m2_q08b_1==8 | m2_q08b_1==9) 	// Answers to questions 8A and 8B are too inconsistent, impossible to determine actual education level

* General Secondary Education
replace ISCED_v=3 if m2_q08a==4 & (m2_q08b_1==3 & m2_q08b<=12) 	// less than or equal to 12 years of general secondary education, and highest level completed is basic education -> highest level is basic education

* Secondary Education 
replace ISCED_v=3 if m2_q08a==5 & (m2_q08b_1==3 & m2_q08b<=12)	// less than or equal to 12 years and reported secondary education vocational, and highest level completed is basic education -> highest level is basic education
replace ISCED_v=5 if m2_q08a==5 & (m2_q08b_1==4 & m2_q08b<=12)	// less than or equal to 12 years and reported secondary education vocational, and highest level completed is general secondary education -> highest level is general secondary education
replace ISCED_v=3 if m2_q08a==5 & (m2_q08b_1==5 & m2_q08b<10)	// less than or equal to 10 years and reported secondary education vocational, and highest level completed is secondary education vocational -> highest level is basic education

* Vocational Level 4 & 5 
replace ISCED_v=3 if m2_q08a==6 & (m2_q08b_1==3 & m2_q08b<=2)	// less than or equal to 2 years and reported vocational level 4 and 5, and highest level is basic education -> highest level is basic education
replace ISCED_v=5 if m2_q08a==6 & (m2_q08b_1==4 & m2_q08b<=2)	// less than or equal to 2 years and reported vocational level 4 and 5, and highest level is general secondary education -> highest level is general secondary education
replace ISCED_v=4 if m2_q08a==6 & (m2_q08b_1==5 & m2_q08b<=3)	// less than or equal to 3 years and reported vocational level 4 and 5, and highest level is secondary education vocational -> highest level is secondary education vocational
replace ISCED_v=4 if m2_q08a==6 & (m2_q08b_1==6 & m2_q08b==12)	// Special case: Reported being at vocational level 4 and 5 and level is correct but years of education is 12, which is inconsistent -> Recode as Secondary vocational 

* Bachelor (non medicine)
replace ISCED_v=3 if m2_q08a==7 & (m2_q08b_1==3)				 // Typo: level should be Basic Education
replace ISCED_v=5 if m2_q08a==7 & (m2_q08b_1==4)				 // less than or equal to 2 years and reported bachelor, and highest level completed is general secondary eduaction -> highest level is general secondary education.
replace ISCED_v=4 if m2_q08a==7 & (m2_q08b_1==5 & m2_q08b<4)	 // less than or equal to 4 years and reported bachelor, and highest level completed is secondary education vocational -> highest level is secondary education vocational
replace ISCED_v=8 if m2_q08a==7 & (m2_q08b_1==6 & m2_q08b<=4)	 // less than or equal to 4 years and reported bachelor, and highest level completed is vocational level 4 and 5 -> highest level is vocational level 4 and 5
replace ISCED_v=5 if m2_q08a==7 & (m2_q08b_1==7 & m2_q08b<=2)	 // less than or equal to 2 years and reported bachelor, and highest level completed is bachelor -> highest level is general secondary education
replace ISCED_v=5 if m2_q08a==7 & (m2_q08b_1==7 & m2_q08b==11)	 // Respondent reports holding a bachelor's degree, but years of education are consistent with secondary education -> highest level is general secondary education


* Bachelor (medicine)
replace ISCED_v=5 if m2_q08a==8 & (m2_q08b_1==4 & m2_q08b<=5)	 // less than or equal to 5 years and reported bachelor in medicine, and highest level completed is general secondary eduaction -> highest level is general secondary education.
replace ISCED_v=8 if m2_q08a==8 & (m2_q08b_1==6 & m2_q08b<=7)	 // less than or equal to 7 years and reported bachelor in medicine, and highest level completed is vocational level 4 and 5 -> highest level is vocational level 4 and 5
replace ISCED_v=5 if m2_q08a==8 & (m2_q08b_1==7 & m2_q08b<6)	 // less than 6 years in the medicine bachelor's course -> highest level is general secondary education
replace ISCED_v=5 if m2_q08a==8 & (m2_q08b_1==8 & m2_q08b<6)	 // less than 6 years in the medicine bachelor's course -> highest level is general secondary education

* Masters
replace ISCED_v=5 if m2_q08a==9 & (m2_q08b_1==4 & m2_q08b<2)	 // less than 2 years and reported masters, and highest level completed is general secondary eduaction -> highest level is general secondary education.
replace ISCED_v=4 if m2_q08a==9 & (m2_q08b_1==5 & m2_q08b<12)	 // less than 12 years and reported masters, and highest level completed is secondary vocational education -> highest level is general secondary education.
replace ISCED_v=8 if m2_q08a==9 & (m2_q08b_1==6 & m2_q08b<2)	 // less than 2 years and reported masters, and highest level completed is vocational level 4 & 5 -> highest level is vocational level 4 and 5
																									
replace ISCED_v=0 if m2_q02==2  							 /*Did not attend school*/

recode m2_q15 (1=0) (2=1) (3=3) (4=5) (5=4) (6=8) (7=9) (8=9) (9=9), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<.		/* Use m2_q15 "Other certificate or diploma?" to correct highest level of edcuation completed if relevant*/


*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED)


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if (m2_q08a==7 | m2_q08a==8) & ISCED_p==.  /*Bachelor's degree*/
replace ISCED_p=7 if m2_q08a==9 & ISCED_p==. /*Master's degree*/
	replace ISCED_p=6 if ISCED_p==7 & m2_q08a==9 & m2_q08b_1==7	//These respondents reported having completed one year of the Master's degree course, and holding a Bachelor's as their highest level completed
replace ISCED_p=8 if m2_q08a==10 & ISCED_p==. /*PhD degree*/
	replace ISCED_p=7 if ISCED_p==8 & m2_q08a==10 & m2_q08b_1==8	//These respondents reported having completed less than 3 years of a Doctorate course, and holding a Master's as their highest level completed
replace ISCED_p=9 if m2_q08a<. & ISCED_p==.
replace ISCED_p=10 if m2_q08a==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*current attending level
recode m2_q20l (1=0) (2=1) (3=3) (4=5) (5=4) (6=8) (7=9) (8=9) (9=9) (10=9) (99=.), gen(current_ISCED_v) 
recode m2_q20l (1=0) (2=1) (3=2) (4=3) (5=3) (6=5) (7=6) (8=6) (9=7) (10=8) (99=.), gen(current_ISCED_p)
recode m2_q20l (1=0) (2=1) (3=2) (4=3) (5=3) (6=5) (7=5) (8=5) (9=5) (10=5) (99=.), gen(current_ISCED)

*level before dropout
recode m2_q24l (1=0) (2=1) (3=3) (4=5) (5=4) (6=8) (7=9) (8=9) (9=9) (10=9) (99=.), gen(dropout_ISCED_v) 
recode m2_q24l (1=0) (2=1) (3=2) (4=3) (5=3) (6=5) (7=6) (8=6) (9=7) (10=8) (99=.), gen(dropout_ISCED_p)
recode m2_q24l (1=0) (2=1) (3=2) (4=3) (5=3) (6=5) (7=5) (8=5) (9=5) (10=5) (99=.), gen(dropout_ISCED)


* NUMBER OF YEARS OF EDUCATION ACTUALLY COMPLETED (TR)
gen years_educ_act=0 if m2_q02==2 											// No formal education
replace years_educ_act=0 if m2_q08a==1										// No grade completed
replace years_educ_act=m2_q08b if m2_q08a==2 								// Primary school
replace years_educ_act=m2_q08b if m2_q08a==3 & m2_q08b>8 & m2_q08b<.		// Basic Education
replace years_educ_act=6+m2_q08b if m2_q08a==3 & m2_q08b<8					// Basic Education
	notes: Individuals who reported being in basic education but reported 1 or 4 years of education, assuming these are years in addition to primary. 
replace years_educ_act=m2_q08b if m2_q08a==4 & m2_q08b>8 & m2_q08b<.		// General Secondary education
replace years_educ_act=6+3+m2_q08b if m2_q08a==4 & m2_q08b<8				// General Secondary education
	notes: Individuals who reported being in general secondary education but reported 1 year of education, assuming these are years in addtion to primary and basic education.
replace years_educ_act=m2_q08b if m2_q08a==5 & m2_q08b>9 & m2_q08b<.		// Secondary education - vocational
replace years_educ_act=6+3+m2_q08b if m2_q08a==5 & m2_q08b<9				// Secondary education - vocational
	notes: Individuals who reported being in secondary education vocational but reported 1 to 4 years of education, assuming these are years in addtion to primary and basic education.
replace years_educ_act=6+3+3+m2_q08b if m2_q08a==5 & m2_q08b<9				// Vocational level 4 and 5
	notes: Individuals who reported being in vocational level 4 and 5 but reported 1 to 4 years of education, assuming these are years in addtion to primary, basic education, and secondary.
replace years_educ_act=m2_q08b if m2_q08a==6 & m2_q08b==12 					// Vocational level 4 and 5
	notes: Individuals who reported being in vocational level 4 and 5 but reported 12 years of education, assuming these are the total years of education. 
replace years_educ_act=6+3+3+m2_q08b if m2_q08a==7 & m2_q08b<=5  			// Bachelor
	notes: Individuals who reported being in bachelor but reported less or equal to 5 years of education, assuming these are years in addtion to primary, basic education, and secondary.
replace years_educ_act=6+3+3+m2_q08b if m2_q08a==7 & m2_q08b>9 & m2_q08b<.   // Bachelor
	notes: Individuals who reported being in bachelor but reported more than 9 years of education, assuming these are years in addtion to primary, basic education, and secondary.
replace years_educ_act=m2_q08b if m2_q08a==7 & m2_q08b>5 & m2_q08b<9		// Bachelor
	notes: Individuals who reported being in bachelor but reported between 5 and 9 years of education, assuming these are the total years of education. 
replace years_educ_act=6+3+3+m2_q08b if m2_q08a==8 							// Bachelor (medicine) 
	notes: Individuals who reported being in bachelor but reported 1 to 7 years of education, assuming these are years in addtion to primary, basic education, and secondary.
replace years_educ_act=6+3+3+4+m2_q08b if m2_q08a==9						// Masters 
	notes: Individuals who reported being in masters but reported 1 to 12 years of education, assuming these are years in addtion to primary, basic education, and secondary.
replace years_educ_act=6+3+3+4+2+m2_q08b if m2_q08a==10						// Masters 
	notes: Individuals who reported being in bachelor but reported 1 to 10 years of education, assuming these are years in addtion to primary, basic education, and secondary.

* Correct for m2_q15 - i.e. if a higher certificate or diploma was obtained
replace years_educ_act=6+3 if (m2_q15>m2_q08a) & m2_q15!=. & m2_q08a!=. & m2_q15==4			// General Secondary Education 
replace years_educ_act=6+3+3 if (m2_q15>m2_q08a) & m2_q15!=. & m2_q08a!=. & m2_q15==5		// Secondary Education - vocational
replace years_educ_act=6+3+3+2 if (m2_q15>m2_q08a) & m2_q15!=. & m2_q08a!=. & m2_q15==6		// Vocational level 4 and 5
replace years_educ_act=6+3+3+4 if (m2_q15>m2_q08a) & m2_q15!=. & m2_q08a!=. & m2_q15==7		// Bachelor
replace years_educ_act=6+3+3+4+2 if (m2_q15>m2_q08a) & m2_q15!=. & m2_q08a!=. & m2_q15==8	// Masters
replace years_educ_act=6+3+3+4+2+3 if (m2_q15>m2_q08a) & m2_q15!=. & m2_q08a!=. & m2_q15==9	// Doctorate

label var years_educ_act "Years of education actually completed"


* NUMBER OF YEARS OF EDUCATION CORRESPONDING TO THE HIGHEST LEVEL COMPLETED (TR)
gen years_educ=0 if ISCED_p==0							// No formal education or less than primary
replace years_educ=6 if ISCED_p==1 						// Primary completed
replace years_educ=6+3 if ISCED_p==2 					// Lower Secondary completed
replace years_educ=6+3+3 if ISCED_p==3 					// Upper Secondary completed
replace years_educ=6+3+3+2 if ISCED_p==5 				// Post Secondary Technical/Vocational
replace years_educ=6+3+3+4 if ISCED_p==6 				// University First Degree - Bachelor
replace years_educ=6+3+3+4+2 if ISCED_p==7 				// University Second Degree - Master
replace years_educ=6+3+3+4+2+3 if ISCED_p==8 			// PhD
/* Following the years of duration stated in the ISCED 97 mapping for Georgia, i.e. 3 years for PhD and no distinction between medicine bachelor's and general bachelor's (44 observations)*/


*FIELD OF EDUCATION
gen highest=m2_q08a
gen highest2=m2_q15
gen hgsteduc=max(highest, highest2)
gen hgstcurrent=m2_q20l
gen hgstdrop=m2_q24l

*Highest field
gen highest_field_1=m2_q09_1 
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q18 if m2_q18~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=m2_q09_2
replace highest_field_2=. if hgsteduc>highest & hgsteduc~=.

drop highest highest2 hgsteduc

*current attending field 
gen current_field=m2_q21 

*field before dropout
gen dropout_field=m2_q25 

*training field
gen training_field_1=m2_q38_1 
gen training_field_2=m2_q38_2


*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q24 (1=0) (2=1) (3=2) (4=3) (5=3) (6=5) (7=5) (8=5) (9=6) (-7/-1=.), gen(ISCED_needed)			
replace ISCED_needed=. if m5b_q24==99
label var ISCED_needed "Education level need for the job"
	notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13>=3 & m2_q13<.

}
/**** END OF GEORGIA ****/

/**** GHANA ****/
if country=="Ghana" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace

		/*LABL: The following are the labels for m2_q08, m2_q15, m2_q21, m2_q26
			01 NO LEVEL COMPLETED (DID NOT COMPLETE PRIMARY) (None or < ISCED 1)
			02 PRIMARY EDUCATION (ISCED 1)
			03 OLD SYSTEM: MSLC (ISCED 2)
			04 OLD SYSTEM: O levels (ISCED 3A)
			05 OLD SYSTEM: A levels (ISCED 3A)
			06 NEW SYSTEM: JSS/ JHS (ISCED 2)
			07 NEW SYSTEM: SSS/ SHS (ISCED 3A)
			08 SECONDARY (POST-BASIC) TECHNICAL/ VOCATIONAL/ AGRICULTURAL CERTIFICATE OR DIPLOMA (ISCED 3B)
			09 TEACHER TRAINING (CERT A) (ISCED 5A)
			10 TEACHER TRAINING (DIPLOMA) (ISCED 5A)
			11 POLYTECHNIC: HIGHER NATIONAL DIPLOMA (ISCED 5B)
			12 OTHER PROFESSIONAL TERTIARY CERTIFICATE OR DIPLOMA (ISCED 5B)
			13 UNIVERSITY FIRST DEGREE (BACHELOR) (ISCED 5A)
			14 UNIVERSITY SECOND DEGREE (MASTERS) (ISCED 5A)
			15 PHD DEGREE (ISCED 6)
*/

*Highest level completed with vocation distinction (ISCED_v)
recode m2_q08al (1=0) (2=1) (3=3) (4=5) (5=5) (6=3) (7=5) (8=4) (9=9) (10=9) (11=8) (12=8) (13=9) (14=9) (15=9), gen(ISCED_v)

*Correct for cases in which a given cycle was not actually completed
	// Note: as Question m2_q08b was not always correctly understood,
	// 		if a respondent reports having completed a cycle in 8B, 
	//		but did not complete all grades of that cycle (in 8A-grade), we will consider that s/he did NOT complete the cycle in question

forvalues x=2/15 {
	tab m2_q08ag m2_q08b if  m2_q08al==`x', missing
}
	
*Primary or less
replace ISCED_v=0 if m2_q08al==2 & ((m2_q08ag<6 & m2_q08ag!=.) | (m2_q08ag==6 & m2_q08b==1))						// Primary school not completed
																													// Note: 17 cases in which reported highest level in 8B is 'Primary' but less than 6 years of primary education completed
*Secondary | Old System
replace ISCED_v=1 if m2_q08al==3 & ((m2_q08ag<4 & m2_q08ag!=.) | (m2_q08ag==4 & m2_q08b<3 & m2_q08b!=.))			// Middle school not completed or did not pass the final exam -> highest level completed is primary
replace ISCED_v=1 if m2_q08al==4 & ((m2_q08ag<3 & m2_q08ag!=.) | (m2_q08ag==3 & m2_q08b<3 & m2_q08b!=.))			// Less than 3 years of Senior secondary school or did not pass MSLC -> highest level completed is primary (i.e. less than lower secondary school)
replace ISCED_v=3 if m2_q08al==4 & (m2_q08ag>=3 & m2_q08ag<5 & m2_q08ag!=.) & m2_q08b<3 & m2_q08b!=.				// At least 3 years of Senior secondary school, but less than 5 and less than MSLC or O levels -> highest level completed is lower secondary school
replace ISCED_v=3 if m2_q08al==4 & ((m2_q08ag>=5 & m2_q08ag!=.) & (m2_q08b<4 & m2_q08b!=.))							// At least 5 years of Senior secondary school but did not pass O levels -> highest level completed is lower secondary school
*Secondary | Current System
replace ISCED_v=1 if m2_q08al==6 & ((m2_q08ag<3 & m2_q08ag!=.) | (m2_q08ag==3 & m2_q08b<6 & m2_q08b!=.))			// Less than 3 years of JSS/JHS or did not pass the final exam -> highest level completed is primary (i.e. less than lower secondary school)
replace ISCED_v=3 if m2_q08al==6 & m2_q08ag==3 & m2_q08b==3		// 3 years of JSS & an MSLC diploma: this respondent is likely to have mixed up the new and old systems
replace ISCED_v=3 if m2_q08al==7 & ((m2_q08ag<3 & m2_q08ag!=.) | (m2_q08b<7 & m2_q08b!=.))							// Less than 3 years of SSS/SHS or did not pass the final exam -> highest level completed is lower secondary school
																													// Note SSS/SHS was 3 years, then 4, then 3 again

*Secondary Post Basic
replace ISCED_v=3 if m2_q08al==8 & ((m2_q08ag<4 & m2_q08ag!=.) & (m2_q08b<7 & m2_q08b!=4 & m2_q08b!=5 & m2_q08b!=.))	// Less than 4 years of post basic secondary and no O level, A level, or SSS/SHS diploma -> highest completed level is lower secondary
replace ISCED_v=4 if m2_q08al==8 & ((m2_q08ag<4 & m2_q08ag!=.) & m2_q08b==8)											// Less than 4 years of post basic secondary although respondent reports Secondary post basic as highest level completed -> highest completed level is upper secondary vocational
replace ISCED_v=5 if m2_q08al==8 & (m2_q08b==4 | m2_q08b==5 | m2_q08b==7)												// Respondent reports O level, A level or SSS/SHS diploma as highest level completed -> highest completed level is upper secondary

*Teacher Training Certificate
//No correction needed, all 16 respondents completed 3 grades and report a teacher training certificate in 8B

*Teacher Training Diploma
replace ISCED_v=3 if m2_q08al==10 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==3					//Less than 3 years completed and reported highest completed level is MSLC -> highest level completed is lower secondary school
replace ISCED_v=5 if m2_q08al==10 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==7		   			//Less than 3 years completed and reported highest level completed is SSS/SHS -> highest level completed is upper secondary school

*Polytechnic Programme
replace ISCED_v=3 if m2_q08al==11 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==3					//Less than 3 years completed and reported highest completed level as MSLC -> highest completed level is lower secondary
replace ISCED_v=5 if m2_q08al==11 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==7					//Less than 3 years completed and reported highest completed level as SSS/SHS -> highest completed level is upper secondary
replace ISCED_v=4 if m2_q08al==11 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==8					//Less than 3 years completed and reported highest completed level as Secondary Post Basic Tech/Voc/Ag -> highest completed level is upper secondary vocational
replace ISCED_v=9 if m2_q08al==11 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==10					//Less than 3 years completed and reported highest completed level as a Teacher's diploma -> highest completed level is higher education 5A
replace ISCED_v=5 if m2_q08al==11 & m2_q08ag==1 & m2_q08b==11								//Only 1 of the 3 years completed and reported highest completed level as a Polytechnic diploma
																							// as the minimum requirement to enter a Polytechnic course is a Secondary School Certificate -> highest completed level is upper secondary
*Other Professional Tertiary (nursing, etc)
replace ISCED_v=3 if m2_q08al==12 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==3					//Less than 3 years completed and reported highest completed level as MSLC -> highest completed level is lower secondary
replace ISCED_v=5 if m2_q08al==12 & m2_q08ag<3 & m2_q08ag!=. & (m2_q08b==5 | m2_q08b==7)	//Less than 3 years completed and reported highest completed level as SSS/SHS or A level -> highest completed level is upper secondary
replace ISCED_v=4 if m2_q08al==12 & m2_q08ag<3 & m2_q08ag!=. & m2_q08b==8					//Less than 3 years completed and reported highest completed level as Secondary Post Basic Tech/Voc/Ag -> highest completed level is upper secondary vocational
replace ISCED_v=5 if m2_q08al==12 & m2_q08ag==1 & m2_q08b==12								//Only 1 of the 3 years completed and reported highest completed level as a Other prof.
																							// as the minimum requirement to enter such courses is a Secondary School Certificate -> highest completed level is upper secondary
replace ISCED_v=9 if m2_q08al==12 & m2_q08ag==3 & m2_q08ag!=. & m2_q08b==10					//3 years completed but reported highest completed level as a Teacher's diploma -> highest completed level is higher education 5A

*University First Degree (Bachelor)
replace ISCED_v=5 if m2_q08al==13 & m2_q08ag<4 & m2_q08ag!=. & m2_q08b==7					//Less than 4 years completed and reported highest completed level as SSS/SHS -> highest completed level is upper secondary
replace ISCED_v=4 if m2_q08al==13 & m2_q08ag<4 & m2_q08ag!=. & m2_q08b==8					//Less than 4 years completed and reported highest completed level as Post Basic Secondary Tech/Voc/Ag -> highest completed level is upper secondary vocational
replace ISCED_v=9 if m2_q08al==13 & m2_q08ag<4 & m2_q08ag!=. & (m2_q08b==9 | m2_q08b==10)	//Less than 4 years completed and reported highest completed level as Teacher's diploma or certificate -> highest completed level is higher education 5A
replace ISCED_v=8 if m2_q08al==13 & m2_q08ag<4 & m2_q08ag!=. & m2_q08b==11					//Less than 4 years completed and reported highest completed level as Polytechnic -> highest completed level is higher education vocational/technical 5B
replace ISCED_v=8 if m2_q08al==13 & m2_q08b==12												//Reported highest completed level as Other Prof. -> highest completed level is higher education vocational/technical 5B

*University Second Degree (Masters)
replace ISCED_v=3 if m2_q08al==14 & m2_q08b==3												//1 year of Masters and reported highest completed level as MSLC -> highest completed level is lower secondary

assert ISCED_v==. if m2_q02==2																												
replace ISCED_v=0 if m2_q02==2  							 /*Did not attend school*/

recode m2_q15 (1=0) (2=1) (3=3) (4=5) (5=5) (6=3) (7=5) (8=4) (9=9) (10=9) (11=8) (12=8) (13=9) (14=9) (15=9), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<.		/* Use m2_q15 "Other certificate or diploma?" to correct highest level of edcuation completed if relevant*/


*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED)


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if m2_q08al==9 | m2_q08al==10 | m2_q08al==13 /*Teacher Certificate or Diploma and Bachelor's degree*/
replace ISCED_p=7 if m2_q08al==14 /*Master's degree*/
replace ISCED_p=8 if m2_q08al==15 /*PhD degree*/ 
replace ISCED_p=5 if m2_q08al==11 | m2_q08al==12 /*ISCED 5B*/
replace ISCED_p=9 if m2_q08al<. & ISCED_p==.
replace ISCED_p=10 if m2_q08al==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*current attending level
recode m2_q20l (1=0) (2=1) (3=3) (4=5) (6=3) (7=5) (8=4) (9=9) (10=9) (11=8) (12=8) (13=9) (14=9) (15=9), gen(current_ISCED_v) 
recode m2_q20l (1=0) (2=1) (6=2) (7=3) (8=3) (9=6) (10=6) (11=5) (12=5) (13=6) (14=7) (15=8), gen(current_ISCED_p)
recode m2_q20l (1=0) (2=1) (6=2) (7=3) (8=3) (9=5) (10=5) (11=5) (12=5) (13=5) (14=5) (15=5), gen(current_ISCED)

*level before dropout
recode m2_q24l (1=0) (2=1) (3=3) (4=5) (6=3) (7=5) (8=4) (9=9) (10=9) (11=8) (12=8) (13=9) (14=9) (15=9), gen(dropout_ISCED_v) 
recode m2_q24l (1=0) (2=1) (3=2) (4=3) (6=2) (7=3) (8=3) (9=6) (10=6) (11=5) (12=5) (13=6) (14=7) (15=8), gen(dropout_ISCED_p)
recode m2_q24l (1=0) (2=1) (3=2) (4=3) (6=2) (7=3) (8=3) (9=5) (10=5) (11=5) (12=5) (13=5) (14=5) (15=5), gen(dropout_ISCED)


* NUMBER OF YEARS OF EDUCATION ACTUALLY COMPLETED (TR)
gen years_educ_act=0 if m2_q02==2 											// No formal education
replace years_educ_act=0 if m2_q08al==1										// No grade completed
replace years_educ_act=m2_q08ag-1 if m2_q08al==2							// Primary school
replace years_educ_act=6+m2_q08ag-1 if m2_q08al==3							// Old system: MSLC, after completion of Primary School
replace years_educ_act=6+m2_q08ag-1 if m2_q08al==4							// Old system: Senior Secondary School, after completion of Primary School
replace years_educ_act=6+m2_q08ag-1 if m2_q08al==6							// New system: JSS/JHS, after completion of Primary School 
replace years_educ_act=6+3+m2_q08ag-1 if m2_q08al==7						// New system: SSS/SHS, after completion of JSS/JHS 
replace years_educ_act=6+3+m2_q08ag-1 if m2_q08al==8						// Secondary Post Basic, after Junior high school
	notes: SSS/SHS was 3 years then 4 years then 3 years again. As the ISCED mapping from the Unesco considers SSS/SHS to be 4 years we use 4 years in codes below, when SSS/SHS was completed 
replace years_educ_act=6+3+4+m2_q08ag-1 if m2_q08al==9 | m2_q08al==10		// Teacher Training Certificate and Diploma, after SSS/SHS 
replace years_educ_act=6+3+4+m2_q08ag-1 if m2_q08al==11						// Polytechnic Programme, after SSS/SHS 
replace years_educ_act=6+3+4+m2_q08ag-1 if m2_q08al==12						// Other Professional Tertiary (nursing, etc), after SSS/SHS 
replace years_educ_act=6+3+4+m2_q08ag-1 if m2_q08al==13						// University First Degree - Bachelor, after SSS/SHS 
replace years_educ_act=6+3+4+4+m2_q08ag-1 if m2_q08al==14					// University Second Degree - Master, after Bachelor 
replace years_educ_act=6+3+4+4+2+m2_q08ag-1 if m2_q08al==15					// PhD, after Master
* Correct for m2_q15 - i.e. if a higher certificate or diploma was obtained
replace years_educ_act=6+5 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==4						//Other diploma is O Level - 5 years after completion of Primary
replace years_educ_act=6+5+2 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==5					//Other diploma is A Level - 2 years after O Level
replace years_educ_act=6+3+4 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==7					//Other diploma is SSS/SHS - 4 years after completing JSS/JHS (assuming 4 years for SSS/SHS)
replace years_educ_act=6+3+4 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==8					//Other diploma is Secondary Post Basic - 4 years after completing JSS/JHS
replace years_educ_act=6+3+4+3 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==9 | m2_q15==10	//Other diploma is Teacher Training Certificate or Diploma - 3 years after completing SSS/SHS
replace years_educ_act=6+3+4+3 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==11				//Other diploma is Polytechnic Programme - 3 years after completing SSS/SHS
replace years_educ_act=6+3+4+3 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==12				//Other diploma is Other Professional Tertiary - 3 years after completing SSS/SHS
replace years_educ_act=6+3+4+4 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==13				//Other diploma is University First Degree - 4 years after completing SSS/SHS
replace years_educ_act=6+3+4+4+2 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==14				//Other diploma is University Second Degree - 2 years after completing Bachelor
replace years_educ_act=6+3+4+4+2+3 if m2_q15>m2_q08al & m2_q15!=. & m2_q08al!=. & m2_q15==15			//Other diploma is PhD - 3 years after completing Master

label var years_educ_act "Years of education actually completed"


* NUMBER OF YEARS OF EDUCATION CORRESPONDING TO THE HIGHEST LEVEL COMPLETED (TR)
gen years_educ=0 if ISCED_p==0							// No formal education or less than primary
replace years_educ=6 if ISCED_p==1 						// Primary completed
replace years_educ=6+3 if ISCED_p==2 					// Lower Secondary completed
replace years_educ=6+3+4 if ISCED_p==3 					// Upper Secondary completed
replace years_educ=6+3+4+3 if ISCED_p==5 				// Post Secondary Technical/Vocational
replace years_educ=6+3+4+4 if ISCED_p==6 				// University First Degree - Bachelor
replace years_educ=6+3+4+4+2 if ISCED_p==7 				// University Second Degree - Master
replace years_educ=6+3+4+4+2+3 if ISCED_p==8 			// PhD
/* Following the years of duration stated in the ISCED 97 mapping for Ghana*/


*FIELD OF EDUCATION
gen highest=m2_q08al
gen highest2=m2_q15
gen hgsteduc=max(highest, highest2)
gen hgstcurrent=m2_q20l
gen hgstdrop=m2_q24l

*Highest field
gen highest_field_1=m2_q09_1 
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q18 if m2_q18~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=m2_q09_2
replace highest_field_2=. if hgsteduc>highest & hgsteduc~=.

drop highest highest2 hgsteduc

*current attending field 
gen current_field=m2_q21 

*field before dropout
gen dropout_field=m2_q25 

*training field
gen training_field_1=m2_q38_1 
gen training_field_2=m2_q38_2


*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q24 (1=0) (2=1) (3=2) (4=3) (6=2) (7=3) (8=3) (9=5) (10=5) (11=5) (12=5) (13=5) (14=5) (15=6), gen(ISCED_needed)
replace ISCED_needed=. if m5b_q24==99
label var ISCED_needed "Education level need for the job"
	notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13>=3 & m2_q13<.
}

/**** END OF GHANA ****/


/**** ARMENIA ****/
if country=="Armenia" {
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 A" 6 "ISCED 4 Voc" 7 "ISCED 4 A" 8 "ISCED 5 Voc" 9 "ISCED 5 A & 6", replace

	/*LABL: The following are the labels for m2_q08, m2_q15, m2_q21, m2_q26
	SOVIET SYSTEM
		02	Primary  (grades 1-3)	(ISCED 1)
		03	Basic general education  (grades 4-8)	(ISCED 2A)
		04	Secondary  (grades 9-10)	(ISCED 3A)
		05	Preliminary Vocational Education (Vocational technical schools)  	(ISCED 3C)
		06	Middle Vocational Education (Public specialized secondary schools)	(ISCED 3B)
		15	Secondary specialized education (after Secondary)	(ISCED 5B)
		07	Higher education establishments	(ISCED 5A)
	PRESENT SYSTEM:	
		08	Primary (grades 1-4)	(ISCED 1)
		09	Basic general education (grades 5-9)	(ISCED 2A)
		10	Secondary general education (grades 10-12)	(ISCED 3A)
		11	Preliminary Vocational Education (Professional  secondary education (after Basic))	(ISCED 3C)
		12	Middle Vocational Education (Secondary specialized education (after Basic))	(ISCED 3B)
		13	Bachelor degree	(ISCED 5A)
		14	Masters degree	(ISCED 5A)
		15	Secondary specialized education (after Secondary)	(ISCED 5B)
		
		16	Candidate of Sience	(ISCED 5A)  
		17	Doctor of Science	(ISCED 6)
		01	No grade completed	(ISCED 0)

*/

*Highest level completed with vocation distinction (ISCED_v)
recode m2_q08a_grade (1=0) (2=1) (3=3) (4=5) (5=4) (6=4) (7=9) (8=1) (9=3) (10=5) (11=4) (12=4) (13=9) (14=9) (15=8) (16=9) (17=9), gen(ISCED_v)
replace ISCED_v=. if m2_q08a_grade==-7
*Correct for cases in which a given cycle was not actually completed
	// Note: as Question m2_q08b was not always correctly understood,
	// 		if a respondent reports having completed a cycle in 8B, 
	//		but did not complete all grades of that cycle (in 8A-grade), we will consider that s/he did NOT complete the cycle in question

forvalues x=1/17 {
	di "m2_q08_a_grade==`x'"
	tab m2_q08a_year m2_q08b if  m2_q08a_grade==`x', missing nolab
}
	
*Primary or Less | Soviet System
/* No observations to correct*/

*Basic General Education | Soviet System
replace ISCED_v=1 if (m2_q08a_grade==3 & (m2_q08a_year<=8 & m2_q08a_year!=-7)) & m2_q08b==2		// Less than or equal to 8 years and reported Basic general education, reported highest level is primary -> highest level completed is primary
replace ISCED_v=1 if (m2_q08a_grade==3 & (m2_q08a_year<8 & m2_q08a_year!=-7)) & m2_q08b==3		// Less than 8 years and reported Basic General Education, repoerted incomplete secondary -> higest level completed is primary 

*Secondary | Soviet System 
replace ISCED_v=3 if (m2_q08a_grade==4 & (m2_q08a_year<=10 & m2_q08a_year!=-7)) & m2_q08b==3  	// Less than 10 years and reported secondary, and highest level is incomplete secondary -> highest level completed is Basic General Education
replace ISCED_v=3 if (m2_q08a_grade==4 & (m2_q08a_year<=10 & m2_q08a_year!=-7)) & m2_q08b==9	// Less than or equal to 10 years and reported secondary, and reported Basic Education Certificate -> higest level completed is Basic General Education  
replace ISCED_v=3 if (m2_q08a_grade==4 & (m2_q08a_year<=10 & m2_q08a_year!=-7)) & m2_q08b==5   	// Less than 10 years and reported secondary, and highest level is preliminary professional diploma -> highest level completed is Basic General Education
replace ISCED_v=3 if (m2_q08a_grade==4 & (m2_q08a_year<=10 & m2_q08a_year!=-7)) & m2_q08b==7   	// Less than 10 years and reported secondary, and highest level is higher education diploma -> highest level completed is Basic General Education

*Preliminary Vocational Education | Soviet System
replace ISCED_v=3 if (m2_q08a_grade==5 & (m2_q08a_year<3 & m2_q08a_year!=-7)) & m2_q08b==3 		// Less than 3 years and reported preliminary vocational education, reported highest level is incomplete secondary  -> highest level completed is Basic General Education
replace ISCED_v=5 if (m2_q08a_grade==5 & (m2_q08a_year<3 & m2_q08a_year!=-7)) & m2_q08b==4 		// Less than 3 years and reported preliminary vocational education, reported highest level is complete secondary -> highest level completed is secondary
replace ISCED_v=3 if (m2_q08a_grade==5 & (m2_q08a_year<3 & m2_q08a_year!=-7)) & m2_q08b==5 		// Less than 3 years and reported preliminary vocational education, reported highest level is preliminary professional diploma  -> highest level completed is Basic General Education

*Middle Vocational Education | Soviet System
replace ISCED_v=3 if (m2_q08a_grade==6 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==3 		// Less than 4 years and reported middle vocational education, reported highest level is incomplete secondary -> highest level completed is Basic General Education
replace ISCED_v=5 if (m2_q08a_grade==6 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==4 	// Less than or equal to 3 years and reported middle vocational education, reported highest level is complete secondary -> highest level completed is secondary
replace ISCED_v=3 if (m2_q08a_grade==6 & (m2_q08a_year<2 & m2_q08a_year!=-7)) & m2_q08b==6 		// Less than 2 years and reported middle vocational education, reported highest level is middle vocational diploma -> highest level completed is Basic General Education
replace ISCED_v=5 if (m2_q08a_grade==6 & (m2_q08a_year<2 & m2_q08a_year!=-7)) & m2_q08b==15 	// Less than 2 years and reported middle vocational education, reported highest level is public specialized secondary diploma -> highest level completed is secondary
replace ISCED_v=3 if (m2_q08a_grade==6 & (m2_q08a_year==3) & m2_q08b==15)						// Equal to 3 or 4 years and reported higher education establishments, reporetd highest level is public specialized secondary diploma -> highest level completed is Basic General Education

*Higher Education Establishments | Soviet System
replace ISCED_v=5 if (m2_q08a_grade==7 & (m2_q08a_year<6 & m2_q08a_year!=-7)) & m2_q08b==4		// Less than 6 years and reported higher education establishments, reported highest level is complete secondary -> highest level completed is secondary 
replace ISCED_v=5 if (m2_q08a_grade==7 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==7		// Less than 4 years and reported higher education establishments, reporetd highest level is higher education diploma -> highest level completed is secondary
replace ISCED_v=8 if (m2_q08a_grade==7 & (m2_q08a_year<6 & m2_q08a_year!=-7)) & m2_q08b==15		// Less than 6 years and reported higher education establishments, reporetd highest level is public specialized secondary diploma -> highest level completed is Public Specialized Secondary


*Primary or Less | Current System
replace ISCED_v=0 if (m2_q08a_grade==8 & (m2_q08a_year==3 & m2_q08a_year!=-7)) & m2_q08b==5		// Equal to 3 years and reported Primary, reported Preliminary Professional Diploma -> highest level completed is No Education or Less than Primary. 

*Basic General Education | Current System
replace ISCED_v=1 if (m2_q08a_grade==9 & (m2_q08a_year<=9 & m2_q08a_year!=-7)) & m2_q08b==2		// Less than 9 years and reported Basic general education, reported highest level is primary -> highest level completed is primary
replace ISCED_v=1 if (m2_q08a_grade==9 & (m2_q08a_year<9 & m2_q08a_year!=-7)) & m2_q08b==9		// Less than 9 years and reported Basic general education, reported highest level is Basic Education Certificate -> highest level completed is primary

*Secondary | Current System 
replace ISCED_v=3 if (m2_q08a_grade==10 & (m2_q08a_year<=12 & m2_q08a_year!=-7)) & m2_q08b==3	// Less than or equal to 12 years and reported secondary, or highest level is incomplete secondary -> highest level completed is Basic General Education
replace ISCED_v=3 if (m2_q08a_grade==10 & (m2_q08a_year<12 & m2_q08a_year!=-7)) & m2_q08b==4	// Less than 12 years and reported secondary, or highest level is complete secondary -> highest level completed is Basic General Education
replace ISCED_v=3 if (m2_q08a_grade==10 & (m2_q08a_year<=12 & m2_q08a_year!=-7)) & m2_q08b==9	// Less than or equal to 10 years and reported secondary, or highest level is basic education certificate -> highest level completed is Basic General Education

*Preliminary Vocational Education | Current System
replace ISCED_v=3 if (m2_q08a_grade==11 & (m2_q08a_year<3 & m2_q08a_year!=-7)) & m2_q08b==3		// Less than 3 years and reported preliminary vocational education, reported highest level is incomplete secondary -> highest level completed is Basic General Education
replace ISCED_v=3 if (m2_q08a_grade==11 & (m2_q08a_year<3 & m2_q08a_year!=-7)) & m2_q08b==9		// Less than 3 years and reported preliminary vocational education, reported highest level is basic education certificate -> highest level completed is Basic General Education
replace ISCED_v=5 if (m2_q08a_grade==11 & (m2_q08a_year==3 & m2_q08a_year!=-7)) & m2_q08b==10	// Equal to 3 years and reported preliminary vocational education, reported highest level is Attestat -> highest level completed is Secondary
replace ISCED_v=3 if (m2_q08a_grade==11 & (m2_q08a_year<3 & m2_q08a_year!=-7)) & m2_q08b==11	// Less than 3 years and reported preliminary vocational education, reported highest level is preliminary professional diploma -> highest level completed is Basic General Education

*Middle Vocational Education | Current System
replace ISCED_v=5 if (m2_q08a_grade==12 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==4		// Less than 3 years and reported middle vocational education, reported highest level is complete secondary -> highest level completed is secondary
replace ISCED_v=3 if (m2_q08a_grade==12 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==9		// Less than 3 years and reported middle vocational education, reported highest level is basic education certificate -> highest level completed is basic general education
replace ISCED_v=5 if (m2_q08a_grade==12 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==10	// Less than 3 years and reported middle vocational education, reported highest level is attestat -> highest level completed is secondary
replace ISCED_v=5 if (m2_q08a_grade==12 & (m2_q08a_year<2 & m2_q08a_year!=-7)) & m2_q08b==12	// Less than 2 years and reported middle vocational education, reported highest level is Middle Vocational Diploma -> highest level completed is secondary

*Bachelors | Current System
replace ISCED_v=5 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==4		// Less than 5 years and reported bachelors, reported highest level is complete secondary  -> highest level completed is Secondary  
replace ISCED_v=3 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==9		// Less than 5 years and reported bachelors, reporetd highest level is basic education certificate -> highest level completed is basic general education
replace ISCED_v=5 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==10	// Less than 5 years and reported bachelors, reported highest level is complete secondary  -> highest level completed is Secondary 
replace ISCED_v=4 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==11	// Less than 5 years and reported bachelors, reported highest level is preliminary professional diploma  -> highest level completed is Secondary (ISCED 3C) 
replace ISCED_v=4 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==12	// Less than 5 years and reported bachelors, reported highest level is middle vocational diploma  -> highest level completed is Secondary (ISCED 3B
replace ISCED_v=5 if (m2_q08a_grade==13 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==13	// Less than 4 years and reported bachelors, reported highest level is bachelors  -> highest level completed is Secondary 
replace ISCED_v=8 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==15	// Less than 5 years and reported bachelors, reported highest level is public specialized secondary diploma  -> highest level completed is public specialized secondary diploma

*Masters | Current System
replace ISCED_v=9 if (m2_q08a_grade==14 & (m2_q08a_year<=2 & m2_q08a_year!=-7)) & m2_q08b==13	// Less than or equal to 2 years and reported masters, reported highest level is bachelors  -> highest level completed is bachelors 

*Secondary Specialized Education | Both Systems
replace ISCED_v=5 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==4	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is incomplete secondary  -> highest level completed is Secondary 
replace ISCED_v=4 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==6	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is preliminary profesional diploma  -> highest level completed is Secondary (ISCED 3C)
replace ISCED_v=5 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==10	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is incomplete secondary  -> highest level completed is Secondary 
replace ISCED_v=4 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==12	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is middle vocational diploma  -> highest level completed is Secondary (ISCED 3B)
replace ISCED_v=5 if (m2_q08a_grade==15 & (m2_q08a_year<2 & m2_q08a_year!=-7)) & m2_q08b==15	// Less than 2 years and reported secondary specialized system, reported highest level is public specialized secondary diploma  -> highest level completed is Secondary

*Candidate of Science | Both Systems
replace ISCED_v=9 if (m2_q08a_grade==16 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==14	// Less than or equal to 3 years and reported candidate of science, reported highest level is bachelors  -> highest level completed is bachelors

* PhD
* All cases specified it correctly.

assert ISCED_v==. if m2_q02==2																												
replace ISCED_v=0 if m2_q02==2  							 /*Did not attend school*/

recode m2_q15 (1=0) (2=1) (3=3) (4=5) (5=4) (6=4) (7=9) (8=1) (9=3) (10=5) (11=4) (12=4) (13=9) (14=9) (15=8) (16=9) (17=9), gen(other_v)
replace ISCED_v=other_v if other_v>ISCED_v & other_v<.		/* Use m2_q15 "Other certificate or diploma?" to correct highest level of edcuation completed if relevant*/

*ISCED
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=3) (8=5) (9=5), gen(ISCED)


**Highest level completed vocational or not
gen educ_voc=1 if     (ISCED_v==2 & other_v==2)|(ISCED_v==2 & other_v==.)|(ISCED_v==2 & other_v<2)
replace educ_voc=1 if (ISCED_v==4 & other_v==4)|(ISCED_v==4 & other_v==.)|(ISCED_v==4 & other_v<4)
replace educ_voc=1 if (ISCED_v==6 & other_v==6)|(ISCED_v==6 & other_v==.)|(ISCED_v==6 & other_v<6)
replace educ_voc=1 if (ISCED_v==8 & other_v==8)|(ISCED_v==8 & other_v==.)|(ISCED_v==8 & other_v<8)

replace educ_voc=3 if (ISCED_v==0 | ISCED_v==1)
replace educ_voc=3 if (ISCED_v==3 & other_v==3)|(ISCED_v==3 & other_v==.)|(ISCED_v==3 & other_v<2)
replace educ_voc=3 if (ISCED_v==5 & other_v==5)|(ISCED_v==5 & other_v==.)|(ISCED_v==5 & other_v<4)
replace educ_voc=3 if (ISCED_v==7 & other_v==7)|(ISCED_v==7& other_v==.)|(ISCED_v==7 & other_v<6)
replace educ_voc=3 if (ISCED_v==9 & other_v==9)|(ISCED_v==9 & other_v==.)|(ISCED_v==9 & other_v<9)

replace educ_voc=2 if (ISCED_v==3 & other_v==2)|(ISCED_v==2 & other_v==3)
replace educ_voc=2 if (ISCED_v==4 & other_v==5)|(ISCED_v==5 & other_v==4)
replace educ_voc=2 if (ISCED_v==6 & other_v==7)|(ISCED_v==7 & other_v==6)
replace educ_voc=2 if (ISCED_v==8 & other_v==9)|(ISCED_v==9 & other_v==8)

label define educ_voc 3 "General degree or none"  2 "General & Vocational degree" 1 "Vocational degree" 
label 	var	educ_voc	"Highest education level completed is vocational/general"
label val educ_voc educ_voc

*HIGHEST ISCED, PIAAC categories
recode ISCED_v (0=0) (1=1) (2=2) (3=2) (4=3) (5=3) (6=4) (7=4) (8=5) (9=.) (10=.), gen(ISCED_p) /*here 4A hasn't been grouped with 3*/
replace ISCED_p=6 if m2_q08a_grade==7 | m2_q08a_grade==13 /*Higher Education Establishment and Bachelor's degree*/
replace ISCED_p=7 if m2_q08a_grade==14 | m2_q08a_grade==16 /*Master's and Candidate of Science degree*/
replace ISCED_p=8 if m2_q08a_grade==17 /*PhD degree*/ 
replace ISCED_p=5 if m2_q08a_grade==15 /*ISCED 5B*/
replace ISCED_p=9 if m2_q08a_grade<. & ISCED_p==.
replace ISCED_p=10 if m2_q08a_grade==. & ISCED_p==. 
notes  ISCED: People who have attended pre-university courses are grouped in ISCED 3. 

*Higher Education Establishments | Soviet System
replace ISCED_p=3 if (m2_q08a_grade==7 & (m2_q08a_year<6 & m2_q08a_year!=-7)) & m2_q08b==4		// Less than 6 years and reported higher education establishments, reported highest level is complete secondary -> highest level completed is secondary 
replace ISCED_p=3 if (m2_q08a_grade==7 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==7		// Less than 4 years and reported higher education establishments, reporetd highest level is higher education diploma -> highest level completed is secondary
replace ISCED_p=5 if (m2_q08a_grade==7 & (m2_q08a_year<6 & m2_q08a_year!=-7)) & m2_q08b==15		// Less than 6 years and reported higher education establishments, reporetd highest level is public specialized secondary diploma -> highest level completed is Public Specialized Secondary

*Bachelors | Current System
replace ISCED_p=3 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==4		// Less than 5 years and reported bachelors, reported highest level is complete secondary  -> highest level completed is Secondary  
replace ISCED_p=2 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==9		// Less than 5 years and reported bachelors, reporetd highest level is basic education certificate -> highest level completed is basic general education
replace ISCED_p=3 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==10	// Less than 5 years and reported bachelors, reported highest level is complete secondary  -> highest level completed is Secondary 
replace ISCED_p=3 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==11	// Less than 5 years and reported bachelors, reported highest level is preliminary professional diploma  -> highest level completed is Secondary (ISCED 3C) 
replace ISCED_p=3 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==12	// Less than 5 years and reported bachelors, reported highest level is middle vocational diploma  -> highest level completed is Secondary (ISCED 3B
replace ISCED_p=3 if (m2_q08a_grade==13 & (m2_q08a_year<4 & m2_q08a_year!=-7)) & m2_q08b==13	// Less than 4 years and reported bachelors, reported highest level is bachelors  -> highest level completed is Secondary 
replace ISCED_p=5 if (m2_q08a_grade==13 & (m2_q08a_year<5 & m2_q08a_year!=-7)) & m2_q08b==15	// Less than 5 years and reported bachelors, reported highest level is public specialized secondary diploma  -> highest level completed is public specialized secondary diploma

*Masters | Current System
replace ISCED_p=6 if (m2_q08a_grade==14 & (m2_q08a_year<=2 & m2_q08a_year!=-7)) & m2_q08b==13	// Less than or equal to 2 years and reported masters, reported highest level is bachelors  -> highest level completed is bachelors 

*Candidate of Science | Both Systems
replace ISCED_p=7 if (m2_q08a_grade==16 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==14	// Less than or equal to 3 years and reported candidate of science, reported highest level is bachelors  -> highest level completed is bachelors

*Secondary Specialized Education | Both Systems
replace ISCED_p=3 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==4	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is incomplete secondary  -> highest level completed is Secondary 
replace ISCED_p=3 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==6	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is preliminary profesional diploma  -> highest level completed is Secondary (ISCED 3C)
replace ISCED_p=3 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==10	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is incomplete secondary  -> highest level completed is Secondary 
replace ISCED_p=3 if (m2_q08a_grade==15 & (m2_q08a_year<=3 & m2_q08a_year!=-7)) & m2_q08b==12	// Less than or equal to 3 years and reported secondary specialized system, reported highest level is middle vocational diploma  -> highest level completed is Secondary (ISCED 3B)
replace ISCED_p=3 if (m2_q08a_grade==15 & (m2_q08a_year<2 & m2_q08a_year!=-7)) & m2_q08b==15	// Less than 2 years and reported secondary specialized system, reported highest level is public specialized secondary diploma  -> highest level completed is Secondary


*current attending level
recode m2_q20l (1=0) (2=1) (3=3) (4=5) (5=4) (6=4) (7=9) (8=1) (9=3) (10=5) (11=4) (12=4) (13=9) (14=9) (15=8) (16=9) (17=9) (-7=.), gen(current_ISCED_v) 
recode m2_q20l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=6) (8=1) (9=2) (10=3) (11=3) (12=3) (13=6) (14=7) (15=5) (16=7) (17=8) (-7=.), gen(current_ISCED_p)
recode m2_q20l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=5) (8=1) (9=2) (10=3) (11=3) (12=3) (13=5) (14=5) (15=5) (16=5) (17=5) (-7=.), gen(current_ISCED)

*level before dropout
recode m2_q24l (1=0) (2=1) (3=3) (4=5) (5=4) (6=4) (7=9) (8=1) (9=3) (10=5) (11=4) (12=4) (13=9) (14=9) (15=8) (16=9) (17=9) (-7=.), gen(dropout_ISCED_v) 
recode m2_q24l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=6) (8=1) (9=2) (10=3) (11=3) (12=3) (13=6) (14=7) (15=5) (16=7) (17=8) (-7=.), gen(dropout_ISCED_p)
recode m2_q24l (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=5) (8=1) (9=2) (10=3) (11=3) (12=3) (13=5) (14=5) (15=5) (16=5) (17=5) (-7=.), gen(dropout_ISCED)


* NUMBER OF YEARS OF EDUCATION ACTUALLY COMPLETED (TR)
gen years_educ_act=0 if m2_q02==2 											// No formal education
replace years_educ_act=0 if m2_q08a_grade==1								// No grade completed
replace years_educ_act=m2_q08a_year if m2_q08a_grade==2						// Primary school (Soviet)
replace years_educ_act=m2_q08a_year if m2_q08a_grade==8						// Primary school (Current)
replace years_educ_act=m2_q08a_year if m2_q08a_grade==3						// Basic General Education (Soviet)
replace years_educ_act=m2_q08a_year if m2_q08a_grade==9						// Basic General Education (Current)
replace years_educ_act=m2_q08a_year if m2_q08a_grade==4						// Secondary (Soviet)
replace years_educ_act=m2_q08a_year if m2_q08a_grade==10					// Secondary (Current)
replace years_educ_act=8+m2_q08a_year if m2_q08a_grade==5					// Preliminary Vocational Education (Soviet)
replace years_educ_act=9+m2_q08a_year if m2_q08a_grade==11					// Preliminary Vocational Education (Current)
replace years_educ_act=8+m2_q08a_year if m2_q08a_grade==6					// Middle Vocational Education (Soviet)
replace years_educ_act=9+m2_q08a_year if m2_q08a_grade==12					// Middle Vocational Education (Current)
replace years_educ_act=10+m2_q08a_year if m2_q08a_grade==15					// Secondary Specialized Education (Both)
	notes: The code for secondary specialized education was the same for both systems, but the duration of secondary differs. The lowest duration (10) was assumed for both systems. 
replace years_educ_act=10+m2_q08a_year if m2_q08a_grade==7					// Higher Education Establishments (Soviet)
replace years_educ_act=12+m2_q08a_year if m2_q08a_grade==13					// Bachelor's Education (Current)
replace years_educ_act=17+m2_q08a_year if m2_q08a_grade==14					// Master's Education (Current)
replace years_educ_act=16+m2_q08a_year if m2_q08a_grade==16					// Candidate of Science (Both)
	notes: The code for secondary specialized education was the same for both systems, but the duration of secondary differs. The lowest duration (16) was assumed for both systems. 
replace years_educ_act=18+m2_q08a_year if m2_q08a_grade==17					// Doctor of Science(Both)
	notes: The code for secondary specialized education was the same for both systems, but the duration of secondary differs. The lowest duration (18) was assumed for both systems. 

* Correct for m2_q15 - i.e. if a higher certificate or diploma was obtained
replace years_educ_act=8+3 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==5			//Other diploma is Preliminary Vocational Education (Soviet)
replace years_educ_act=8+4 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==6			//Other diploma is Middle Vocational Education (Soviet)
replace years_educ_act=10+6 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==7			//Other diploma is Higher Education Diploma (Soviet)
replace years_educ_act=9+3 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==11			//Other diploma is Preliminary Professional Education (Current)
replace years_educ_act=9+4 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==12			//Other diploma is Middle Vocational Education (Current)
replace years_educ_act=12+5 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==13			//Other diploma is Bachelors (Current)
replace years_educ_act=17+2 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==14			//Other diploma is Masters (Current)
replace years_educ_act=10+3 if m2_q15>m2_q08a_grade & m2_q15!=. & m2_q08a_grade!=. & m2_q15==15			//Other diploma is Public Specialized Secondary (Both)

label var years_educ_act "Years of education actually completed"
tab years_educ_act, m

* NUMBER OF YEARS OF EDUCATION CORRESPONDING TO THE HIGHEST LEVEL COMPLETED (TR)

* Version taking into account systems.
gen aux=1 if inrange(m2_q08a_grade,2,7)
replace aux=2 if inrange(m2_q08a_grade,8,14)
gen years_educ=0 if ISCED_p==0							// No formal education or less than primary
replace years_educ=3 if ISCED_p==1 & aux==1				// Primary completed (Soviet)
replace years_educ=4 if ISCED_p==1 & aux==2				// Primary completed (Current)
replace years_educ=8 if ISCED_p==2 & aux==1				// Lower Secondary completed (Soviet)
replace years_educ=9 if ISCED_p==2 & aux==2				// Lower Secondary completed (Current)
replace years_educ=10 if ISCED_p==3 & (m2_q08b==4)		// Upper Secondary completed (Soviet)
replace years_educ=11 if ISCED_p==3 & (m2_q08b==5)		// Upper Secondary completed (Soviet)
replace years_educ=12 if ISCED_p==3 & (m2_q08b==6)		// Upper Secondary completed (Soviet)
replace years_educ=12 if ISCED_p==3 & (m2_q08b==10)	// Upper Secondary completed (Current)
replace years_educ=12 if ISCED_p==3 & (m2_q08b==11)	// Upper Secondary completed (Current)
replace years_educ=13 if ISCED_p==3 & (m2_q08b==12)	// Upper Secondary completed (Current)
replace years_educ=13 if ISCED_p==5 					// Post Secondary Technical/Vocational (Both)
replace years_educ=16 if ISCED_p==6 & aux==1			// University (Soviet)
replace years_educ=17 if ISCED_p==6 & aux==2			// University First Degree - Bachelor (Current)
replace years_educ=19 if ISCED_p==7 & aux==2			// University Second Degree - Master (Current)
replace years_educ=18 if ISCED_p==7 & (m2_q08b==16)		// University Second Degree - Candidate of Science (Both)
replace years_educ=21 if ISCED_p==8 & (m2_q08b==17)		// University Second Degree - PhD (Both)

tab years_educ, m

*FIELD OF EDUCATION
gen highest=m2_q08a_grade if m2_q08a_grade>0
gen highest2=m2_q15 if m2_q15>0
gen hgsteduc=max(highest, highest2)
gen hgstcurrent=m2_q20l if m2_q20l>0
gen hgstdrop=m2_q24l if m2_q24l>0

*Highest field
gen highest_field_1=m2_q09_1 
replace highest_field_1=. if hgsteduc>highest & hgsteduc~=.
replace highest_field_1=m2_q16 if m2_q16~=. & hgsteduc==highest2 & hgsteduc>highest
replace highest_field_1=m2_q18 if m2_q18~=. & hgsteduc==highest2 & hgsteduc>highest

gen highest_field_2=m2_q09_2
replace highest_field_2=. if hgsteduc>highest & hgsteduc~=.

drop highest highest2 hgsteduc

*current attending field 
gen current_field=m2_q21 
replace current_field=. if current_field<0


*field before dropout
gen dropout_field=m2_q25 
replace dropout_field=. if dropout_field<0

*training field
gen training_field_1=m2_q38_1 if m2_q38_1>0
gen training_field_2=m2_q38_2 if m2_q38_2>0


*EDUCATION LEVEL NEEDED FOR JOB
recode m5b_q24 (1=0) (2=1) (3=2) (4=3) (5=3) (6=3) (7=5) (8=5) (9=5) (10=5) (-9/-1=.), gen(ISCED_needed)
label var ISCED_needed "Education level need for the job"
	notes ISCED_needed: Corresponds to main job. 

*DIF B/T EDUCATION AND EDUCATION NEEDED FOR JOB
	gen ISCED_dif= ISCED-ISCED_needed
	*MAKE CORRECTION FOR PhD
	replace ISCED_dif=0 if ISCED_p==8 & ISCED_needed==6
	label var ISCED_dif "Difference between education and education needed for job"
	
*SCHOOL LOCATION
gen school_location=1 if m2_q13==1
replace school_location=2 if m2_q13==2	
replace school_location=3 if m2_q13>=3 & m2_q13<.
}
/**** END OF ARMENIA ****/


****************************
* LABEL VARIABLES EDUCATION *
****************************
label 	var	age	"Age"
label 	var	age2	"Age squared"
label 	var	occtype	"Occupation type"

label 	var	tenure_range	"Time to learn to do job well with experience and education needed expressed as range"
label 	var	ece	"Attended preschool"
label 	var	certificate	"Has an industry-recognized or govt certificate not awarded by a formal ed institution"
label 	var	current	"Currently attending school"
label 	var	dropout	"Dropped out of highest educational level started"
label 	var	interrupt	"Interrupted studies for one academic year or more"
label 	var	training	"Participated in a training course in last 12 months"
label 	var	apprenticeship	"Has completed an apprenticeship"

label 	var	highest_field_1	"Field of highest degree (first reported)"
label 	var	highest_field_2	"Field of highest degree (second reported)"

label   var ISCED_p "Highest ISCED completed, PIAAC" 
label   var ISCED "Highest ISCED completed" 
label   var ISCED_v "Highest ISCED completed, with vocational distinction" 
label 	var	current_ISCED	"ISCED level currently attending"
label 	var	current_ISCED_v	"ISCED currently attending, with vocational distinction"
label 	var	current_field	"Field currently studying"
label 	var	dropout_ISCED	"Highest ISCED level before dropping out"
label 	var	dropout_ISCED_v	"Highest ISCED before dropping out, with vocational distinction"
label 	var	dropout_field	"Field studying before dropping out"

label 	var	training_field_1	"Field of skills training (first reported)"
label 	var	training_field_2	"Field of skills training (second reported)"

label define ISCED 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3 & 4A" 4 "ISCED 4B" 5 "ISCED 5 & 6", replace

label define ISCED_n 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3" 4 "ISCED 4" 5 "ISCED 5"  6 "ISCED 6", replace
label values ISCED_needed ISCED_n
lab define ISCED_p 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2" 3 "ISCED 3A-B" 4 "ISCED 4A-B" ///
                          5 "ISCED 5B"  6 "ISCED 5A, bachelor" 7 "ISCED 5A, master" 8 "ISCED 6" 9 "DK" 10 "RF" , replace
						  
lab define ISCED_v 0 "None or < ISCED 1" 1 "ISCED 1" 2 "ISCED 2 Voc" 3 "ISCED 2 Gen" 4 "ISCED 3 Voc" ///
					5 "ISCED 3 Gen" 6 "ISCED 4 Voc" 7 "ISCED 4 Gen" 8 "ISCED 5 Voc" 9 "ISCED 5 Gen & 6", replace

label values  ISCED ISCED
label values  ISCED_p ISCED_p 
label values  ISCED_v ISCED_v 

label values  current_ISCED ISCED
label values  current_ISCED_v ISCED_v

label values  dropout_ISCED ISCED
label values  dropout_ISCED_v ISCED_v

label var years_educ "Number of years of education corresponding to the highest level completed" 

label define yesno 1 "Yes" 0 "No", replace
label val ece yesno
label val certificate yesno 
lab val current yesno
lab val dropout yesno
lab val interrupt yesno
lab val training yesno
lab val apprenticeship yesno
lab val late_first_grade yesno
label var school_location "School location"
label define school_location 1 "In the same city" 2 "In another city/province" 3 "In another country"   
label values school_location school_location

*THIS SECTION generates:
	*categorical variables for education levels
	*Report higher level than necessary for the job
	*Aggregated education variable
*Report higher ISCED than necessary for the job
gen higher =1 if ISCED_dif>0 & ISCED_dif<.
replace higher=0 if ISCED_dif<. & ISCED_dif<=0
label var higher "Reports higher ISCED level than necessary for the job"
		

*******************
*NEW VOCATIONAL EDUC VARIABLE
******************
gen voc_ISCED=1 if ISCED==0
replace voc_ISCED=2 if ISCED==1 & educ_voc==1
replace voc_ISCED=3 if ISCED==1 & educ_voc==2
replace voc_ISCED=4 if ISCED==1 & educ_voc==3
replace voc_ISCED=5 if ISCED==2 & educ_voc==1
replace voc_ISCED=6 if ISCED==2 & educ_voc==2
replace voc_ISCED=7 if ISCED==2 & educ_voc==3
replace voc_ISCED=8 if ISCED==3 & educ_voc==1
replace voc_ISCED=9 if ISCED==3 & educ_voc==2
replace voc_ISCED=10 if ISCED==3 & educ_voc==3
replace voc_ISCED=11 if ISCED==4 & educ_voc==1
replace voc_ISCED=12 if ISCED==4 & educ_voc==2
replace voc_ISCED=13 if ISCED==4 & educ_voc==3
replace voc_ISCED=14 if ISCED==5 & educ_voc==1
replace voc_ISCED=15 if ISCED==5 & educ_voc==2
replace voc_ISCED=16 if ISCED==5 & educ_voc==3

label define voc_ISCED 1 "ISCED 0" 2 "ISCED 1 Voc" ///
								3 "ISCED 1 Gen & Voc" ///
								4 "ISCED 1 Gen" ///
								5 "ISCED 2 Voc" ///
								6 "ISCED 2 Gen & Voc" ///
								7 "ISCED 2 Gen" ///
								8 "ISCED 3 Voc" ///
								9 "ISCED 3 Gen & Voc" ///
								10 "ISCED 3 Gen" ///
								11 "ISCED 4 Voc" ///
								12 "ISCED 4 Gen & Voc" ///
								13 "ISCED 4 Gen" ///
								14 "ISCED 5 Voc" ///
								15 "ISCED 5 Gen & Voc" ///
								16 "ISCED 5 Gen", replace
label values voc_ISCED voc_ISCED
label var voc_ISCED "ISCED with voc & gen distinction"								
								

**************************************************** END OF EDUCATION SECTION ****************************************************
drop hgstcurrent hgstdrop 

if country=="Armenia" {
drop aux
}

label var country "Country"

	compress
	sort cluster hhn
	save "$pathworkingdata/STEP `country'_working.dta", replace
}


**************************************************************************** END OF STEP DO-FILE 5 ******************************************************************
